@@ -47,7 +47,7 @@
 #include "albumsettings.h"
 #include "albumthumbnailloader.h"
 #include "contextmenuhelper.h"
-#include "metadatamanager.h"
+#include "fileactionmngr.h"
 #include "tagdragdrop.h"
 #include "tagmodificationhelper.h"
 
@@ -1058,7 +1058,10 @@ void AbstractAlbumTreeView::handleCustomContextMenuAction(QAction* action, Album
 
 void AbstractAlbumTreeView::albumSettingsChanged()
 {
-    d->delegate->updateHeight();
+    if (d->delegate)
+    {
+        d->delegate->updateHeight();
+    }
 }
 
 // ----------------------------------------------------------------------------------------------
@@ -1419,9 +1422,6 @@ void AlbumTreeView::setAlbumModel(AlbumModel* model)
     {
         m_dragDropHandler = new AlbumDragDropHandler(albumModel());
 
-        connect(m_dragDropHandler, SIGNAL(dioResult(KJob*)),
-                this, SLOT(slotDIOResult(KJob*)));
-
         model->setDragDropHandler(m_dragDropHandler);
     }
 }
@@ -1446,17 +1446,6 @@ PAlbum* AlbumTreeView::albumForIndex(const QModelIndex& index) const
     return dynamic_cast<PAlbum*> (m_albumFilterModel->albumForIndex(index));
 }
 
-void AlbumTreeView::slotDIOResult(KJob* kjob)
-{
-    KIO::Job* job = static_cast<KIO::Job*>(kjob);
-
-    if (job->error())
-    {
-        job->ui()->setWindow(this);
-        job->ui()->showErrorMessage();
-    }
-}
-
 void AlbumTreeView::setCurrentAlbum(PAlbum* album, bool selectInAlbumManager)
 {
     AbstractCheckableAlbumTreeView::setCurrentAlbum(album, selectInAlbumManager);
@@ -1526,7 +1515,7 @@ void TagTreeView::setAlbumModel(TagModel* model)
         albumModel()->setDragDropHandler(m_dragDropHandler);
 
         connect(albumModel()->dragDropHandler(), SIGNAL(assignTags(QList<qlonglong>,QList<int>)),
-                MetadataManager::instance(), SLOT(assignTags(QList<qlonglong>,QList<int>)));
+                FileActionMngr::instance(), SLOT(assignTags(QList<qlonglong>,QList<int>)));
     }
 
     if (m_albumModel->rootAlbumBehavior() == AbstractAlbumModel::IncludeRootAlbum)
