@@ -114,6 +114,7 @@ public:
 
     DImg                    originalImage;
     DImg                    cropImage;
+    FilterAction            lastFilterAction;
 
     GreycstorationSettings* settingsWidget;
 
@@ -150,16 +151,16 @@ InPaintingTool::InPaintingTool(QObject* parent)
     // -------------------------------------------------------------
 
     d->gboxSettings = new EditorToolSettings;
-    d->gboxSettings->setButtons(EditorToolSettings::Default|
-                                EditorToolSettings::Ok|
-                                EditorToolSettings::Try|
-                                EditorToolSettings::Load|
-                                EditorToolSettings::SaveAs|
+    d->gboxSettings->setButtons(EditorToolSettings::Default |
+                                EditorToolSettings::Ok |
+                                EditorToolSettings::Try |
+                                EditorToolSettings::Load |
+                                EditorToolSettings::SaveAs |
                                 EditorToolSettings::Cancel);
 
     // -------------------------------------------------------------
 
-    d->mainTab               = new KTabWidget( d->gboxSettings->plainPage());
+    d->mainTab               = new KTabWidget(d->gboxSettings->plainPage());
     QWidget* firstPage       = new QWidget(d->mainTab);
 
     KUrlLabel* cimgLogoLabel = new KUrlLabel();
@@ -222,8 +223,8 @@ InPaintingTool::InPaintingTool(QObject* parent)
 
     // -------------------------------------------------------------
 
-    connect(cimgLogoLabel, SIGNAL(leftClickedUrl(const QString&)),
-            this, SLOT(processCImgUrl(const QString&)));
+    connect(cimgLogoLabel, SIGNAL(leftClickedUrl(QString)),
+            this, SLOT(processCImgUrl(QString)));
 
     connect(d->inpaintingTypeCB, SIGNAL(activated(int)),
             this, SLOT(slotResetValues(int)));
@@ -352,10 +353,9 @@ void InPaintingTool::processCImgUrl(const QString& url)
 void InPaintingTool::prepareEffect()
 {
     ImageIface iface(0, 0);
-    uchar* data      = iface.getOriginalImage();
+    QScopedArrayPointer<uchar> data(iface.getOriginalImage());
     d->originalImage = DImg(iface.originalWidth(), iface.originalHeight(),
-                            iface.originalSixteenBit(), iface.originalHasAlpha(), data);
-    delete [] data;
+                            iface.originalSixteenBit(), iface.originalHasAlpha(), data.data());
 
     // Selected area from the image and mask creation:
     //
@@ -374,16 +374,16 @@ void InPaintingTool::prepareEffect()
     QPixmap inPaintingMask(iface.originalWidth(), iface.originalHeight());
     inPaintingMask.fill(Qt::black);
     QPainter p(&inPaintingMask);
-    p.fillRect( selectionRect, QBrush(Qt::white) );
+    p.fillRect(selectionRect, QBrush(Qt::white));
     p.end();
 
     GreycstorationContainer settings = d->settingsWidget->settings();
 
-    int x1 = (int)(selectionRect.left()   - 2*settings.amplitude);
-    int y1 = (int)(selectionRect.top()    - 2*settings.amplitude);
-    int x2 = (int)(selectionRect.right()  + 2*settings.amplitude);
-    int y2 = (int)(selectionRect.bottom() + 2*settings.amplitude);
-    d->maskRect = QRect(x1, y1, x2-x1, y2-y1);
+    int x1 = (int)(selectionRect.left()   - 2 * settings.amplitude);
+    int y1 = (int)(selectionRect.top()    - 2 * settings.amplitude);
+    int x2 = (int)(selectionRect.right()  + 2 * settings.amplitude);
+    int y2 = (int)(selectionRect.bottom() + 2 * settings.amplitude);
+    d->maskRect = QRect(x1, y1, x2 - x1, y2 - y1);
 
     // Mask area normalization.
     // We need to check if mask area is out of image size else inpainting give strange results.
@@ -436,20 +436,23 @@ void InPaintingTool::putPreviewData()
     GreycstorationContainer settings = d->settingsWidget->settings();
 
     d->cropImage = filter()->getTargetImage();
-    QRect cropSel((int)(2*settings.amplitude), (int)(2*settings.amplitude),
+    QRect cropSel((int)(2 * settings.amplitude), (int)(2 * settings.amplitude),
                   iface->selectedWidth(), iface->selectedHeight());
     DImg imDest = d->cropImage.copy(cropSel);
 
     iface->putPreviewImage((imDest.smoothScale(iface->previewWidth(),
-                            iface->previewHeight())).bits());
+                                               iface->previewHeight())).bits());
     d->previewWidget->updatePreview();
     d->isComputed = true;
+    d->lastFilterAction = filter()->filterAction();
 }
 
 void InPaintingTool::putFinalData()
 {
     ImageIface iface(0, 0);
 
+    // Note: if d->isComputed, filter() will be deleted but results stored
+
     if (!d->isComputed)
     {
         d->cropImage = filter()->getTargetImage();
@@ -457,23 +460,25 @@ void InPaintingTool::putFinalData()
 
     d->originalImage.bitBltImage(&d->cropImage, d->maskRect.left(), d->maskRect.top());
 
-    iface.putOriginalImage(i18n("In-Painting"), filter()->filterAction(), d->originalImage.bits());
+    iface.putOriginalImage(i18n("In-Painting"),
+                           filter() ? filter()->filterAction() : d->lastFilterAction,
+                           d->originalImage.bits());
 }
 
 void InPaintingTool::slotLoadSettings()
 {
     KUrl loadInpaintingFile = KFileDialog::getOpenUrl(KGlobalSettings::documentPath(),
-                              QString( "*" ), kapp->activeWindow(),
-                              QString( i18n("Photograph In-Painting Settings File to Load")) );
+                                                      QString("*"), kapp->activeWindow(),
+                                                      QString(i18n("Photograph In-Painting Settings File to Load")));
 
-    if ( loadInpaintingFile.isEmpty() )
+    if (loadInpaintingFile.isEmpty())
     {
         return;
     }
 
     QFile file(loadInpaintingFile.toLocalFile());
 
-    if ( file.open(QIODevice::ReadOnly) )
+    if (file.open(QIODevice::ReadOnly))
     {
         if (!d->settingsWidget->loadSettings(file, QString("# Photograph Inpainting Configuration File V2")))
         {
@@ -499,17 +504,17 @@ void InPaintingTool::slotLoadSettings()
 void InPaintingTool::slotSaveAsSettings()
 {
     KUrl saveRestorationFile = KFileDialog::getSaveUrl(KGlobalSettings::documentPath(),
-                               QString( "*" ), kapp->activeWindow(),
-                               QString( i18n("Photograph In-Painting Settings File to Save")) );
+                                                       QString("*"), kapp->activeWindow(),
+                                                       QString(i18n("Photograph In-Painting Settings File to Save")));
 
-    if ( saveRestorationFile.isEmpty() )
+    if (saveRestorationFile.isEmpty())
     {
         return;
     }
 
     QFile file(saveRestorationFile.toLocalFile());
 
-    if ( file.open(QIODevice::WriteOnly) )
+    if (file.open(QIODevice::WriteOnly))
     {
         d->settingsWidget->saveSettings(file, QString("# Photograph Inpainting Configuration File V2"));
     }
