@@ -454,7 +454,7 @@ static void* greycstoration_thread(void *arg) {
       p.temporary = 0;
       p.counter = 0;
       p.tile = p.tile_border = p.thread = p.nb_threads = 0;
-      p.stop_request = false;
+      (*p.stop_request) = false;
       greycstoration_mutex_destroy(p);
     }
     p.is_running = false;
