@@ -58,6 +58,8 @@
 #include "databasebackend.h"
 #include "databasetransaction.h"
 #include "databaseoperationgroup.h"
+#include "imagecomments.h"
+#include "imagecopyright.h"
 #include "imageinfo.h"
 #include "imagescanner.h"
 #include "tagscache.h"
@@ -848,7 +850,8 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
         itemIdSet << scanInfos.at(i).id;
     }
 
-    const QFileInfoList list = dir.entryInfoList(QDir::AllDirs | QDir::Files  | QDir::NoDotAndDotDot);
+    const QFileInfoList list = dir.entryInfoList(QDir::AllDirs | QDir::Files | QDir::NoDotAndDotDot,
+                                                 QDir::Name | QDir::DirsLast);
 
     QFileInfoList::const_iterator fi;
 
@@ -889,7 +892,7 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
                 scanFileNormal(*fi, scanInfos.at(index));
             }
             // ignore temp files we created ourselves
-            else if (fi->completeSuffix() == "digikamtempfile.tmp")
+            else if (fi->completeSuffix().contains("digikamtempfile."))
             {
                 continue;
             }
@@ -1017,15 +1020,17 @@ qlonglong CollectionScanner::scanNewFile(const QFileInfo& info, int albumId)
         return -1;
     }
 
-    DatabaseOperationGroup group;
     ImageScanner scanner(info);
     scanner.setCategory(category(info));
+    // call loadFromDisk, which can take long, explicitly to perform it before opening a database transaction
+    scanner.loadFromDisk();
 
     // Check copy/move hints for single items
     qlonglong srcId = d->itemHints.value(NewlyAppearedFile(albumId, info.fileName()));
 
     if (srcId != 0)
     {
+        DatabaseOperationGroup group;
         scanner.copiedFrom(albumId, srcId);
     }
     else
@@ -1041,11 +1046,13 @@ qlonglong CollectionScanner::scanNewFile(const QFileInfo& info, int albumId)
 
         if (srcId != 0)
         {
+            DatabaseOperationGroup group;
             scanner.copiedFrom(albumId, srcId);
         }
         else
         {
             // Establishing identity with the unique hsah
+            DatabaseOperationGroup group;
             scanner.newFile(albumId);
         }
     }
@@ -1061,9 +1068,10 @@ qlonglong CollectionScanner::scanNewFileFullScan(const QFileInfo& info, int albu
         return -1;
     }
 
-    DatabaseOperationGroup group;
     ImageScanner scanner(info);
     scanner.setCategory(category(info));
+    scanner.loadFromDisk();
+    DatabaseOperationGroup group;
     scanner.newFileFullScan(albumId);
     d->finishScanner(scanner);
     return scanner.id();
@@ -1076,9 +1084,10 @@ void CollectionScanner::scanModifiedFile(const QFileInfo& info, const ItemScanIn
         return;
     }
 
-    DatabaseOperationGroup group;
     ImageScanner scanner(info, scanInfo);
     scanner.setCategory(category(info));
+    scanner.loadFromDisk();
+    DatabaseOperationGroup group;
     scanner.fileModified();
     d->finishScanner(scanner);
 }
@@ -1086,9 +1095,10 @@ void CollectionScanner::scanModifiedFile(const QFileInfo& info, const ItemScanIn
 QString CollectionScanner::scanFileUpdateHash(const QFileInfo& info, const ItemScanInfo& scanInfo)
 {
     // same code as scanModifiedFile
-    DatabaseOperationGroup group;
     ImageScanner scanner(info, scanInfo);
     scanner.setCategory(category(info));
+    scanner.loadFromDisk();
+    DatabaseOperationGroup group;
     scanner.fileModified();
     d->finishScanner(scanner);
     return scanner.itemScanInfo().uniqueHash;
@@ -1101,22 +1111,69 @@ void CollectionScanner::rescanFile(const QFileInfo& info, const ItemScanInfo& sc
         return;
     }
 
-    DatabaseOperationGroup group;
     ImageScanner scanner(info, scanInfo);
     scanner.setCategory(category(info));
+    scanner.loadFromDisk();
+    DatabaseOperationGroup group;
     scanner.rescan();
     d->finishScanner(scanner);
 }
 
-void CollectionScanner::copyFileProperties(const ImageInfo& source, const ImageInfo& dest)
+void CollectionScanner::copyFileProperties(const ImageInfo& source, const ImageInfo& d)
 {
-    if (source.isNull() || dest.isNull())
+    if (source.isNull() || d.isNull())
     {
         return;
     }
+    ImageInfo dest(d);
 
     DatabaseOperationGroup group;
-    ImageScanner::copyProperties(source.id(), dest.id());
+
+    kDebug() << "Copying properties from" << source.id() << "to" << dest.id();
+
+    // Rating, creation dates
+    DatabaseFields::ImageInformation imageInfoFields =
+        DatabaseFields::Rating |
+        DatabaseFields::CreationDate |
+        DatabaseFields::DigitizationDate;
+    QVariantList imageInfos = DatabaseAccess().db()->getImageInformation(source.id(), imageInfoFields);
+    if (!imageInfos.isEmpty())
+    {
+        DatabaseAccess().db()->changeImageInformation(dest.id(), imageInfos, imageInfoFields);
+    }
+
+    // Copy public tags
+    foreach (int tagId, TagsCache::instance()->publicTags(source.tagIds()))
+    {
+        dest.setTag(tagId);
+    }
+    // Copy color and pick label
+    dest.setPickLabel(source.pickLabel());
+    dest.setColorLabel(source.colorLabel());
+    // important: skip other internal tags, such a history tags. Therefore AlbumDB::copyImageTags is not to be used.
+
+    // GPS data
+    QVariantList positionData = DatabaseAccess().db()->getImagePosition(source.id(), DatabaseFields::ImagePositionsAll);
+    if (!positionData.isEmpty())
+    {
+        DatabaseAccess().db()->addImagePosition(dest.id(), positionData, DatabaseFields::ImagePositionsAll);
+    }
+
+    // Comments
+    {
+        DatabaseAccess access;
+        ImageComments commentsSource(access, source.id());
+        ImageComments commentsDest(access, dest.id());
+        commentsDest.replaceFrom(commentsSource);
+        commentsDest.apply(access);
+    }
+
+    // Copyright info
+    ImageCopyright copyrightDest(dest.id());
+    copyrightDest.replaceFrom(source.id());
+
+    // Image Properties
+    DatabaseAccess().db()->copyImageProperties(source.id(), dest.id());
 }
 
 void CollectionScanner::itemsWereRemoved(const QList<qlonglong> &removedIds)
