@@ -55,19 +55,19 @@ namespace Digikam
 {
 
 ImageScanner::ImageScanner(const QFileInfo& info, const ItemScanInfo& scanInfo)
-    : m_hasImage(false), m_hasMetadata(false),
+    : m_hasImage(false), m_hasMetadata(false), m_loadedFromDisk(false),
       m_fileInfo(info), m_scanInfo(scanInfo), m_scanMode(ModifiedScan), m_hasHistoryToResolve(false)
 {
 }
 
 ImageScanner::ImageScanner(const QFileInfo& info)
-    : m_hasImage(false), m_hasMetadata(false),
+    : m_hasImage(false), m_hasMetadata(false), m_loadedFromDisk(false),
       m_fileInfo(info), m_scanMode(ModifiedScan), m_hasHistoryToResolve(false)
 {
 }
 
 ImageScanner::ImageScanner(qlonglong imageid)
-    : m_hasImage(false), m_hasMetadata(false), m_scanMode(ModifiedScan), m_hasHistoryToResolve(false)
+    : m_hasImage(false), m_hasMetadata(false), m_loadedFromDisk(false), m_scanMode(ModifiedScan), m_hasHistoryToResolve(false)
 {
     ItemShortInfo shortInfo;
     {
@@ -345,7 +345,17 @@ void ImageScanner::scanImageInformation()
     }
     else // ModifiedScan
     {
-        // Does _not_ update rating and orientation!
+        // Does _not_ update rating and orientation (unless dims were exchanged)!
+        /*int orientation = m_metadata.getImageOrientation();
+        QVariantList data = DatabaseAccess().db()->getImageInformation(m_scanInfo.id,
+                                                                       DatabaseFields::Width |
+                                                                       DatabaseFields::Height |
+                                                                       DatabaseFields::Orientation);
+        if (data.size() == 3 && data[2].isValid() && data[2].toInt() != orientation)
+        {
+            // be careful not to overwrite our value set in the database
+            // But there is a special case: if the dims were
+        }*/
         DatabaseAccess().db()->changeImageInformation(m_scanInfo.id, infos,
                 DatabaseFields::Width      |
                 DatabaseFields::Height     |
@@ -1147,46 +1157,15 @@ void ImageScanner::scanAudioFile()
             DatabaseFields::Format);
 }
 
-void ImageScanner::copyProperties(qlonglong source, qlonglong dest)
-{
-    kDebug() << "Copying properties from" << source << "to" << dest;
-    DatabaseAccess access;
-
-    DatabaseFields::ImageInformation imageInfoFields =
-        DatabaseFields::Rating |
-        DatabaseFields::CreationDate |
-        DatabaseFields::DigitizationDate;
-    QVariantList imageInfos = access.db()->getImageInformation(source, imageInfoFields);
-
-    if (!imageInfos.isEmpty())
-    {
-        access.db()->changeImageInformation(dest, imageInfos, imageInfoFields);
-    }
-
-    QVariantList positionData = access.db()->getImagePosition(source, DatabaseFields::ImagePositionsAll);
-
-    if (!positionData.isEmpty())
-    {
-        access.db()->addImagePosition(dest, positionData, DatabaseFields::ImagePositionsAll);
-    }
-
-    ImageComments commentsSource(access, source);
-    ImageComments commentsDest(access, dest);
-    commentsDest.replaceFrom(commentsSource);
-    commentsDest.apply(access);
-
-    ImageCopyright copyrightSource(source);
-    ImageCopyright copyrightDest(dest);
-    copyrightDest.replaceFrom(source);
-
-    access.db()->copyImageTags(source, dest);
-    access.db()->copyImageProperties(source, dest);
-}
-
 void ImageScanner::loadFromDisk()
 {
-    m_metadata.registerMetadataSettings();
+    if (m_loadedFromDisk)
+    {
+        return;
+    }
+    m_loadedFromDisk = true;
 
+    m_metadata.registerMetadataSettings();
     m_hasMetadata = m_metadata.load(m_fileInfo.filePath());
 
     if (m_scanInfo.category == DatabaseItem::Image)
