@@ -6,7 +6,7 @@
  * Date        : 2005-17-07
  * Description : A Gaussian Blur threaded image filter.
  *
- * Copyright (C) 2005-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009      by Andi Clemens <andi dot clemens at googlemail dot com>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
@@ -40,11 +40,11 @@ class DIGIKAM_EXPORT BlurFilter : public DImgThreadedFilter
 
 public:
 
-    explicit BlurFilter(QObject* parent = 0);
-    explicit BlurFilter(DImg* orgImage, QObject* parent=0, int radius=3);
+    explicit BlurFilter(QObject* const parent = 0);
+    explicit BlurFilter(DImg* const orgImage, QObject* const parent=0, int radius=3);
 
     // Constructor for slave mode: execute immediately in current thread with specified master filter
-    explicit BlurFilter(DImgThreadedFilter* parentFilter, const DImg& orgImage, const DImg& destImage,
+    explicit BlurFilter(DImgThreadedFilter* const parentFilter, const DImg& orgImage, const DImg& destImage,
                         int progressBegin=0, int progressEnd=100, int radius=3);
 
     ~BlurFilter();
@@ -53,14 +53,17 @@ public:
     {
         return "digikam:BlurFilter";
     }
+
     static QString          DisplayableName()
     {
         return I18N_NOOP("Blur Filter");
     }
+
     static QList<int>       SupportedVersions()
     {
         return QList<int>() << 1;
     }
+
     static int              CurrentVersion()
     {
         return 1;
@@ -70,7 +73,9 @@ public:
     {
         return FilterIdentifier();
     }
+
     virtual FilterAction    filterAction();
+
     void                    readParameters(const FilterAction& action);
 
 private:
@@ -80,7 +85,7 @@ private:
     void gaussianBlurImage(uchar* data, int width, int height, bool sixteenBit, int radius);
 
     // function to allocate a 2d array
-    int** Alloc2DArray (int Columns, int Rows)
+    int** Alloc2DArray(int Columns, int Rows)
     {
         // First, we declare our future 2d array to be returned
         int** lpcArray = 0L;
@@ -97,7 +102,7 @@ private:
     };
 
     // Function to deallocates the 2d array previously created
-    void Free2DArray (int** lpcArray, int Columns)
+    void Free2DArray(int** lpcArray, int Columns)
     {
         // loop to deallocate the columns
         for (int i = 0; i < Columns; ++i)
@@ -109,7 +114,7 @@ private:
         delete [] lpcArray;
     };
 
-    inline bool IsInside (int Width, int Height, int X, int Y)
+    inline bool IsInside(int Width, int Height, int X, int Y)
     {
         bool bIsWOk = ((X < 0) ? false : (X >= Width ) ? false : true);
         bool bIsHOk = ((Y < 0) ? false : (Y >= Height) ? false : true);
