@@ -29,6 +29,10 @@
 
 #include <QtCore/QByteArray>
 
+// KDE includes
+
+#include <kurl.h>
+
 // LibKExiv2 includes
 
 #include <libkexiv2/kexiv2.h>
@@ -44,13 +48,15 @@
 #include "metadatainfo.h"
 #include "digikam_export.h"
 
+using namespace KExiv2Iface;
+
 namespace Digikam
 {
 
 class Template;
 class IccProfile;
 
-class DIGIKAM_EXPORT DMetadata : public KExiv2Iface::KExiv2
+class DIGIKAM_EXPORT DMetadata : public KExiv2
 {
 
 public:
@@ -65,6 +71,8 @@ public:
 
     /** Re-implemented from libKexiv2 to use dcraw identify method if Exiv2 failed. */
     bool load(const QString& filePath) const;
+    bool save(const QString& filePath) const;
+    bool applyChanges() const;
 
     /** Try to extract metadata using dcraw identify method */
     bool loadUsingDcraw(const QString& filePath) const;
@@ -165,6 +173,17 @@ public:
 
     static KExiv2::AltLangMap toAltLangMap(const QVariant& var);
 
+    // These methods have been factored to libkexiv2 2.3.0. Remove it after KDE 4.8.2
+#if KEXIV2_VERSION < 0x020300
+    static QString sidecarPath(const QString& path);
+    /** Like KExiv2::sidecarFilePathForFile, but works for remote URLs */
+    static KUrl sidecarUrl(const KUrl& url);
+    /** Gives a file url for a local path */
+    static KUrl sidecarUrl(const QString& path);
+    /** Performs a QFileInfo based check if the given local file has a sidecar */
+    static bool hasSidecar(const QString& path);
+#endif // KEXIV2_VERSION < 0x020300
+
     //------------------------------------------------------------------------------------------------
     // Pushed to libkexiv2 for KDE4.4
 
