@@ -48,6 +48,7 @@
 #include "dmetadata.h"
 #include "iccmanager.h"
 #include "jpegutils.h"
+#include "metadatasettings.h"
 #include "thumbnailloadthread.h"
 #include "thumbnailcreator.h"
 
@@ -229,7 +230,7 @@ void ThumbnailLoadingTask::execute()
 void ThumbnailLoadingTask::setupCreator()
 {
     m_creator->setThumbnailSize(m_loadingDescription.previewParameters.size);
-    m_creator->setExifRotate(m_loadingDescription.previewParameters.exifRotate());
+    m_creator->setExifRotate(MetadataSettings::instance()->settings().exifRotate);
     m_creator->setLoadingProperties(this, m_loadingDescription.rawDecodingSettings);
 }
 
