@@ -51,7 +51,10 @@
 #include "graphicsdimgitem.h"
 #include "itemvisibilitycontroller.h"
 
+namespace
+{
 static const int HANDLE_SIZE = 15;
+}
 
 namespace Digikam
 {
@@ -186,7 +189,7 @@ CropHandle RegionFrameItem::RegionFrameItemPriv::handleAt(const QPointF& pos) co
 {
     if (flags & ShowResizeHandles)
     {
-        foreach (const CropHandle& handle, cropHandleList)
+        foreach(const CropHandle& handle, cropHandleList)
         {
             QRectF rect = handleRect(handle);
 
@@ -545,7 +548,7 @@ void RegionFrameItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*,
     static const QColor outerColor  = QColor::fromHsvF(0, 0, 0, 0.5);
 
     QRegion outerRegion = QRegion(imageRect) - QRegion(rect);
-    foreach (const QRect& outerRect, outerRegion.rects())
+    foreach(const QRect& outerRect, outerRegion.rects())
     {
         painter->fillRect(outerRect, outerColor);
     }
@@ -567,7 +570,7 @@ void RegionFrameItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*,
         {
             painter->setOpacity(d->resizeHandleVisibility->opacity());
             painter->setBrush(fillColor);
-            foreach (const CropHandle& handle, d->cropHandleList)
+            foreach(const CropHandle& handle, d->cropHandleList)
             {
                 QRectF rect = d->handleRect(handle);
                 painter->drawRect(rect);
@@ -636,8 +639,8 @@ void RegionFrameItem::mouseMoveEvent(QGraphicsSceneMouseEvent* event)
 {
     const QSizeF maxSize = parentDImgItem()->boundingRect().size();
     const QPointF point  = mapToParent(event->pos());
-    qreal posX           = qBound(0., point.x(), maxSize.width());
-    qreal posY           = qBound(0., point.y(), maxSize.height());
+    qreal posX           = qBound<qreal>(0., point.x(), maxSize.width());
+    qreal posY           = qBound<qreal>(0., point.y(), maxSize.height());
     QRectF r             = rect();
 
     // Adjust edge
