@@ -209,7 +209,7 @@ ShowFoto::ShowFoto(const KUrl::List& urlList)
 
     if (d->splash)
     {
-        d->splash->message(i18n("Checking ICC repository"));
+        d->splash->message(i18n("Checking ICC repository..."));
     }
     d->validIccPath = Digikam::SetupICC::iccRepositoryIsValid();
 
@@ -217,7 +217,7 @@ ShowFoto::ShowFoto(const KUrl::List& urlList)
 
     if (d->splash)
     {
-        d->splash->message(i18n("Loading themes"));
+        d->splash->message(i18n("Loading themes..."));
     }
     Digikam::ThemeManager::instance();
 
@@ -559,11 +559,8 @@ void ShowFoto::applySettings()
         m_fileDeleteAction->setText(i18n("Delete File"));
     }
 
-    bool exifRotate = group.readEntry("EXIF Rotate", true);
-    m_canvas->setExifOrient(exifRotate);
-    d->thumbBar->setExifRotate(exifRotate);
-
-    m_setExifOrientationTag   = group.readEntry("EXIF Set Orientation", true);
+    /*bool exifRotate = group.readEntry("EXIF Rotate", true);
+    m_setExifOrientationTag   = group.readEntry("EXIF Set Orientation", true);*/
 
     Digikam::ThumbBarToolTipSettings settings;
     settings.showToolTips   = group.readEntry("Show ToolTips", true);
