@@ -36,10 +36,32 @@ using namespace Digikam;
 
 QTEST_KDEMAIN(AdvancedRenameWidgetTest, GUI)
 
-const QString fileName("advancedrename_testimage.jpg");
-const QString fileName2("advancedrename_testimage2.jpg");
-const QString filePath(KDESRCDIR+fileName);
-const QString filePath2(KDESRCDIR+fileName2);
+const QString imagesDir("advancedrenameimages/");
+
+QString createFilePath(const QString& file)
+{
+    return QString(KDESRCDIR + imagesDir + file);
+}
+
+const QString fileName  = "advancedrename_testimage.jpg";
+const QString fileName2 = "advancedrename_testimage2.jpg";
+const QString fileName3 = "001a.jpg";
+const QString fileName4 = "test.png";
+const QString fileName5 = "myfile.jpg";
+const QString fileName6 = "my_file.jpg";
+const QString fileName7 = "holiday_spain_2011_img001.jpg";
+const QString fileName8 = "my images.jpg";
+const QString fileName9 = "holiday_spain_2011_001img.jpg";
+
+const QString filePath = createFilePath(fileName);
+const QString filePath2 = createFilePath(fileName2);
+const QString filePath3 = createFilePath(fileName3);
+const QString filePath4 = createFilePath(fileName4);
+const QString filePath5 = createFilePath(fileName5);
+const QString filePath6 = createFilePath(fileName6);
+const QString filePath7 = createFilePath(fileName7);
+const QString filePath8 = createFilePath(fileName8);
+const QString filePath9 = createFilePath(fileName9);
 
 void AdvancedRenameWidgetTest::testFileNameToken()
 {
@@ -60,12 +82,29 @@ void AdvancedRenameWidgetTest::testFileExtensionToken_data()
     QTest::addColumn<QString>("parseString");
     QTest::addColumn<QString>("result");
 
-    QTest::newRow(fileName.toAscii())  << QString("[ext]") << QString("jpg.jpg");
-    QTest::newRow("[ext]_lala_####") << QString("[ext]_lala_####") << QString("jpg_lala_0001.jpg");
-    QTest::newRow("[ext]_lala_####[ext]") << QString("[ext]_lala_####[ext]") << QString("jpg_lala_0001jpg.jpg");
-    QTest::newRow("[ext]_lala_####.[ext]") << QString("[ext]_lala_####.[ext]") << QString("jpg_lala_0001.jpg");
-    QTest::newRow("[ext]_lala_####.[ext]{upper}") << QString("[ext]_lala_####.[ext]{upper}") << QString("jpg_lala_0001.JPG");
-    QTest::newRow("[ext]_lala_####[ext]{upper}") << QString("[ext]_lala_####[ext]{upper}") << QString("jpg_lala_0001JPG.jpg");
+    QTest::newRow(fileName.toAscii())
+            << QString("[ext]")
+            << QString("jpg.jpg");
+
+    QTest::newRow("[ext]_lala_####")
+            << QString("[ext]_lala_####")
+            << QString("jpg_lala_0001.jpg");
+
+    QTest::newRow("[ext]_lala_####[ext]")
+            << QString("[ext]_lala_####[ext]")
+            << QString("jpg_lala_0001jpg.jpg");
+
+    QTest::newRow("[ext]_lala_####.[ext]")
+            << QString("[ext]_lala_####.[ext]")
+            << QString("jpg_lala_0001.jpg");
+
+    QTest::newRow("[ext]_lala_####.[ext]{upper}")
+            << QString("[ext]_lala_####.[ext]{upper}")
+            << QString("jpg_lala_0001.JPG");
+
+    QTest::newRow("[ext]_lala_####[ext]{upper}")
+            << QString("[ext]_lala_####[ext]{upper}")
+            << QString("jpg_lala_0001JPG.jpg");
 }
 
 void AdvancedRenameWidgetTest::testFileExtensionToken()
@@ -89,8 +128,7 @@ void AdvancedRenameWidgetTest::testFileOwnerToken()
 {
     QList<ParseSettings> files;
     ParseSettings ps;
-    QString filePath = KDESRCDIR"/test.png";
-    ps.fileUrl = KUrl(filePath);
+    ps.fileUrl = KUrl(filePath4);
     files << ps;
     AdvancedRenameManager manager(files);
     manager.parseFiles("[user]");
@@ -103,7 +141,7 @@ void AdvancedRenameWidgetTest::testFileOwnerToken()
     QVERIFY(!userName.isEmpty());
 
     QString result = userName + ".png";
-    QString parsed = manager.newName(filePath);
+    QString parsed = manager.newName(filePath4);
 
     QCOMPARE(parsed, result);
 }
@@ -112,8 +150,7 @@ void AdvancedRenameWidgetTest::testFileGroupToken()
 {
     QList<ParseSettings> files;
     ParseSettings ps;
-    QString filePath = KDESRCDIR"/test.png";
-    ps.fileUrl = KUrl(filePath);
+    ps.fileUrl = KUrl(filePath4);
     files << ps;
     AdvancedRenameManager manager(files);
     manager.parseFiles("[group]");
@@ -126,7 +163,7 @@ void AdvancedRenameWidgetTest::testFileGroupToken()
     QVERIFY(!groupName.isEmpty());
 
     QString result = groupName + ".png";
-    QString parsed = manager.newName(filePath);
+    QString parsed = manager.newName(filePath4);
 
     QCOMPARE(parsed, result);
 }
@@ -138,17 +175,26 @@ void AdvancedRenameWidgetTest::testDirectoryNameToken_data()
 
     // The main directory of digikam can have different names, depending on how the
     // user named it. Therefore we have to detect the name here:
-    const KUrl dir2up = KUrl(KDESRCDIR).upUrl();
+    const KUrl dir2up = KUrl(KDESRCDIR + imagesDir).upUrl();
     const QString dir2upString = dir2up.url();
-    QString digikamDir = dir2upString.right(dir2upString.size()-dir2up.upUrl().url().size());
+    QString digikamDir = dir2upString.right(dir2upString.size() - dir2up.upUrl().url().size());
     digikamDir.chop(1);
 
-    QTest::newRow("[dir]")          << QString("[dir]")          << QString("tests.jpg");
-    QTest::newRow("[dir.]")         << QString("[dir.]")         << QString("%1.jpg").arg(digikamDir);
-    QTest::newRow("[dir.]_[dir]")   << QString("[dir.]_[dir]")   << QString("%1_tests.jpg").arg(digikamDir);
+    QTest::newRow("[dir]")
+            << QString("[dir]")
+            << QString("advancedrenameimages.jpg");
+
+    QTest::newRow("[dir.]")
+            << QString("[dir.]")
+            << QString("%1.jpg").arg(digikamDir);
+
+    QTest::newRow("[dir.]_[dir]")
+            << QString("[dir.]_[dir]")
+            << QString("%1_advancedrenameimages.jpg").arg(digikamDir);
+
     QTest::newRow("[dir......................................................................]")
-       << QString("[dir......................................................................]")
-       << fileName;
+            << QString("[dir......................................................................]")
+            << fileName;
 }
 
 void AdvancedRenameWidgetTest::testDirectoryNameToken()
@@ -173,13 +219,33 @@ void AdvancedRenameWidgetTest::testNumberToken_data()
     QTest::addColumn<QString>("parseString");
     QTest::addColumn<QString>("result");
 
-    QTest::newRow("#")                      << QString("#")                      << QString("1.jpg");
-    QTest::newRow("####[2,3]")              << QString("####[2,3]")              << QString("0002.jpg");
-    QTest::newRow("####[2,3]_bla_## ###")   << QString("####[2,3]_bla_## ###")   << QString("0002_bla_01 001.jpg");
-    QTest::newRow("####[2,3]_bla_## ###")   << QString("####[2,3]_bla_## ###")   << QString("0002_bla_01 001.jpg");
-    QTest::newRow("####[2,3]_bla_## ###")   << QString("####[2,3]_bla_## ###")   << QString("0002_bla_01 001.jpg");
-    QTest::newRow("###[100]_bla")           << QString("###[100]_bla")           << QString("100_bla.jpg");
-    QTest::newRow("###[e,1,100]_bla")       << QString("###[e,1,100]_bla")       << QString("001_bla.jpg");
+    QTest::newRow("#")
+            << QString("#")
+            << QString("1.jpg");
+
+    QTest::newRow("####[2,3]")
+            << QString("####[2,3]")
+            << QString("0002.jpg");
+
+    QTest::newRow("####[2,3]_bla_## ###")
+            << QString("####[2,3]_bla_## ###")
+            << QString("0002_bla_01 001.jpg");
+
+    QTest::newRow("####[2,3]_bla_## ###")
+            << QString("####[2,3]_bla_## ###")
+            << QString("0002_bla_01 001.jpg");
+
+    QTest::newRow("####[2,3]_bla_## ###")
+            << QString("####[2,3]_bla_## ###")
+            << QString("0002_bla_01 001.jpg");
+
+    QTest::newRow("###[100]_bla")
+            << QString("###[100]_bla")
+            << QString("100_bla.jpg");
+
+    QTest::newRow("###[e,1,100]_bla")
+            << QString("###[e,1,100]_bla")
+            << QString("001_bla.jpg");
 }
 
 void AdvancedRenameWidgetTest::testNumberToken()
@@ -206,44 +272,44 @@ void AdvancedRenameWidgetTest::testFirstLetterOfEachWordUppercaseModifier_data()
     QTest::addColumn<QString>("result");
 
     QTest::newRow("myfile")
-        << QString("[file]{firstupper}")
-        << QString("myfile.jpg")
-        << QString("Myfile.jpg");
+            << QString("[file]{firstupper}")
+            << filePath5
+            << QString("Myfile.jpg");
 
     QTest::newRow("my_file")
-        << QString("[file]{firstupper}")
-        << QString("my_file.jpg")
-        << QString("My_File.jpg");
+            << QString("[file]{firstupper}")
+            << filePath6
+            << QString("My_File.jpg");
 
     QTest::newRow("holiday_spain_2011_img001")
-        << QString("[file]{firstupper}")
-        << QString("holiday_spain_2011_img001.jpg")
-        << QString("Holiday_Spain_2011_Img001.jpg");
+            << QString("[file]{firstupper}")
+            << filePath7
+            << QString("Holiday_Spain_2011_Img001.jpg");
 
     QTest::newRow("holiday_spain_2011_001img")
-        << QString("[file]{firstupper}")
-        << QString("holiday_spain_2011_001img.jpg")
-        << QString("Holiday_Spain_2011_001Img.jpg");
+            << QString("[file]{firstupper}")
+            << filePath9
+            << QString("Holiday_Spain_2011_001Img.jpg");
 
     QTest::newRow("001a")
-        << QString("[file]{firstupper}")
-        << QString("001a.jpg")
-        << QString("001A.jpg");
+            << QString("[file]{firstupper}")
+            << filePath3
+            << QString("001A.jpg");
 
     QTest::newRow("my images")
-        << QString("[file]{firstupper}")
-        << QString("my images.jpg")
-        << QString("My Images.jpg");
+            << QString("[file]{firstupper}")
+            << filePath8
+            << QString("My Images.jpg");
 
     QTest::newRow("<empty>")
-        << QString("[file]{firstupper}")
-        << QString("")
-        << QString("");
+            << QString("[file]{firstupper}")
+            << QString("")
+            << QString("");
 
     QTest::newRow(fileName.toAscii())
-        << QString("[file]{firstupper}")
-        << fileName
-        << QString("Advancedrename_Testimage.jpg");
+            << QString("[file]{firstupper}")
+            << filePath
+            << QString("Advancedrename_Testimage.jpg");
 }
 
 void AdvancedRenameWidgetTest::testFirstLetterOfEachWordUppercaseModifier()
@@ -268,8 +334,13 @@ void AdvancedRenameWidgetTest::testChainedModifiers_data()
     QTest::addColumn<QString>("parseString");
     QTest::addColumn<QString>("result");
 
-    QTest::newRow("[file]*{upper}") << QString("[file]{firstupper}{upper}") << QString("ADVANCEDRENAME_TESTIMAGE.jpg");
-    QTest::newRow("[file]{range:3,}*") << QString("[file]{range:3,}{firstupper}")    << QString("Vancedrename_Testimage.jpg");
+    QTest::newRow("[file]*{upper}")
+            << QString("[file]{firstupper}{upper}")
+            << QString("ADVANCEDRENAME_TESTIMAGE.jpg");
+
+    QTest::newRow("[file]{range:3,}*")
+            << QString("[file]{range:3,}{firstupper}")
+            << QString("Vancedrename_Testimage.jpg");
 
     QTest::newRow("[file]{range:3,}{replace:\"name\",\"age\"}{firstupper}")
             << QString("[file]{range:3,}{replace:\"name\",\"age\"}{firstupper}")
@@ -337,25 +408,32 @@ void AdvancedRenameWidgetTest::testReplaceModifier_data()
     QTest::addColumn<QString>("result");
 
     QTest::newRow("[file]{replace:\"adv\",\"AAA\"}")
-            << QString("[file]{replace:\"adv\",\"AAA\"}") << QString("AAAancedrename_testimage.jpg");
+            << QString("[file]{replace:\"adv\",\"AAA\"}")
+            << QString("AAAancedrename_testimage.jpg");
 
     QTest::newRow("[file]{replace:\"Adv\",\"AAA\"}")
-            << QString("[file]{replace:\"Adv\",\"AAA\"}") << QString("advancedrename_testimage.jpg");
+            << QString("[file]{replace:\"Adv\",\"AAA\"}")
+            << QString("advancedrename_testimage.jpg");
 
     QTest::newRow("[file]{replace:\"Adv\",\"AAA\",i}")
-            << QString("[file]{replace:\"Adv\",\"AAA\",i}") << QString("AAAancedrename_testimage.jpg");
+            << QString("[file]{replace:\"Adv\",\"AAA\",i}")
+            << QString("AAAancedrename_testimage.jpg");
 
     QTest::newRow("[file]{replace:\"Adv\",\"AAA\",ri}")
-            << QString("[file]{replace:\"Adv\",\"AAA\",ri}") << QString("AAAancedrename_testimage.jpg");
+            << QString("[file]{replace:\"Adv\",\"AAA\",ri}")
+            << QString("AAAancedrename_testimage.jpg");
 
     QTest::newRow("[file]{replace:\"Adv\",\"AAA\",ir}")
-            << QString("[file]{replace:\"Adv\",\"AAA\",ir}") << QString("AAAancedrename_testimage.jpg");
+            << QString("[file]{replace:\"Adv\",\"AAA\",ir}")
+            << QString("AAAancedrename_testimage.jpg");
 
     QTest::newRow("[file]{replace:\"a.v\",\"AAA\"}")
-            << QString("[file]{replace:\"a.v\",\"AAA\"}") << QString("advancedrename_testimage.jpg");
+            << QString("[file]{replace:\"a.v\",\"AAA\"}")
+            << QString("advancedrename_testimage.jpg");
 
     QTest::newRow("[file]{replace:\"a.v\",\"AAA\",r}")
-            << QString("[file]{replace:\"a.v\",\"AAA\",r}") << QString("AAAancedrename_testimage.jpg");
+            << QString("[file]{replace:\"a.v\",\"AAA\",r}")
+            << QString("AAAancedrename_testimage.jpg");
 }
 
 void AdvancedRenameWidgetTest::testReplaceModifier()
@@ -382,11 +460,25 @@ void AdvancedRenameWidgetTest::testRangeModifier_data()
 
     QDateTime curdate = QDateTime::currentDateTime();
 
-    QTest::newRow("[file]{range:1}")    << QString("[file]{range:1}")   << QString("a.jpg");
-    QTest::newRow("[file]{range:3}")    << QString("[file]{range:3}")   << QString("v.jpg");
-    QTest::newRow("[file]{range:1,3}")  << QString("[file]{range:1,3}") << QString("adv.jpg");
-    QTest::newRow("[file]{range:3,}")   << QString("[file]{range:3,}")  << QString("vancedrename_testimage.jpg");
-    QTest::newRow("[file]{range:0}")    << QString("[file]{range:0}")   << QString("advancedrename_testimage.jpg");
+    QTest::newRow("[file]{range:1}")
+            << QString("[file]{range:1}")
+            << QString("a.jpg");
+
+    QTest::newRow("[file]{range:3}")
+            << QString("[file]{range:3}")
+            << QString("v.jpg");
+
+    QTest::newRow("[file]{range:1,3}")
+            << QString("[file]{range:1,3}")
+            << QString("adv.jpg");
+
+    QTest::newRow("[file]{range:3,}")
+            << QString("[file]{range:3,}")
+            << QString("vancedrename_testimage.jpg");
+
+    QTest::newRow("[file]{range:0}")
+            << QString("[file]{range:0}")
+            << QString("advancedrename_testimage.jpg");
 }
 
 void AdvancedRenameWidgetTest::testRangeModifier()
@@ -413,10 +505,12 @@ void AdvancedRenameWidgetTest::testDefaultValueModifier_data()
 
     QDateTime curdate = QDateTime::currentDateTime();
 
-    QTest::newRow("[meta:Iptc.Application2.Keywords]_[file]") << QString("[meta:Iptc.Application2.Keywords]{default:\"Unknown\"}_[file]")
+    QTest::newRow("[meta:Iptc.Application2.Keywords]_[file]")
+            << QString("[meta:Iptc.Application2.Keywords]{default:\"Unknown\"}_[file]")
             << QString("Colca Canyon_advancedrename_testimage.jpg");
 
-    QTest::newRow("[meta:Exif.GPSInfo.GPSAltitude]_[file]") << QString("[meta:Exif.GPSInfo.GPSAltitude]{default:\"Unknown\"}_[file]")
+    QTest::newRow("[meta:Exif.GPSInfo.GPSAltitude]_[file]")
+            << QString("[meta:Exif.GPSInfo.GPSAltitude]{default:\"Unknown\"}_[file]")
             << QString("Unknown_advancedrename_testimage.jpg");
 }
 
