@@ -6,7 +6,7 @@
  * Date        : 2009-08-08
  * Description : an option to provide metadata information to the parser
  *
- * Copyright (C) 2009 by Andi Clemens <andi dot clemens at googlemail dot com>
+ * Copyright (C) 2009-2012 by Andi Clemens <andi dot clemens at googlemail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -49,8 +49,8 @@
 namespace Digikam
 {
 
-MetadataOptionDialog::MetadataOptionDialog(Parseable* parent) :
-    ParseableDialog(parent),
+MetadataOptionDialog::MetadataOptionDialog(Rule* parent) :
+    RuleDialog(parent),
     metadataPanel(0),
     separatorLineEdit(0)
 {
@@ -88,7 +88,7 @@ MetadataOptionDialog::MetadataOptionDialog(Parseable* parent) :
     QGridLayout* mainLayout = new QGridLayout(this);
     mainLayout->addWidget(customLabel,       0, 0, 1, 1);
     mainLayout->addWidget(separatorLineEdit, 0, 1, 1, 1);
-    mainLayout->addWidget(tab,               1, 0, 1,-1);
+    mainLayout->addWidget(tab,               1, 0, 1, -1);
     mainWidget->setLayout(mainLayout);
 
     // --------------------------------------------------------
