@@ -6,7 +6,7 @@
  * Date        : 2009-08-08
  * Description : an option to add a sequence number to the parser
  *
- * Copyright (C) 2009 by Andi Clemens <andi dot clemens at googlemail dot com>
+ * Copyright (C) 2009-2012 by Andi Clemens <andi dot clemens at googlemail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -27,7 +27,7 @@
 // Local includes
 
 #include "option.h"
-#include "parseabledialog.h"
+#include "ruledialog.h"
 
 class KIntNumInput;
 
@@ -39,13 +39,13 @@ class SequenceNumberOptionDialogWidget;
 namespace Digikam
 {
 
-class SequenceNumberDialog : public ParseableDialog
+class SequenceNumberDialog : public RuleDialog
 {
     Q_OBJECT
 
 public:
 
-    SequenceNumberDialog(Parseable* parent);
+    SequenceNumberDialog(Rule* parent);
     ~SequenceNumberDialog();
 
     Ui::SequenceNumberOptionDialogWidget* const ui;
