@@ -6,7 +6,7 @@
  * Date        : 2011-08-03
  * Description : digital camera thumbnails controller
  *
- * Copyright (C) 2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -49,7 +49,7 @@ class CameraThumbsCtrl::CameraThumbsCtrlPriv
 public:
 
     CameraThumbsCtrlPriv()
-      : controller(0)
+        : controller(0)
     {}
 
     QCache<KUrl, CachedItem> cache;  // Camera info/thumb cache based on item url keys.
@@ -86,13 +86,14 @@ CameraThumbsCtrl::~CameraThumbsCtrl()
     delete d;
 }
 
-CachedItem CameraThumbsCtrl::getThumbInfo(const CamItemInfo& info) const
+bool CameraThumbsCtrl::getThumbInfo(const CamItemInfo& info, CachedItem& item) const
 {
     // We look if items are not in cache.
 
     if (hasItemFromCache(info.url()))
     {
-        return *retrieveItemFromCache(info.url());
+        item = *retrieveItemFromCache(info.url());
+        return true;
         // kDebug() << "Found in cache: " << info.url();
     }
 
@@ -105,7 +106,15 @@ CachedItem CameraThumbsCtrl::getThumbInfo(const CamItemInfo& info) const
         d->controller->getThumbsInfo(CamItemInfoList() << info);
     }
 
-    return CachedItem(info, d->controller->mimeTypeThumbnail(info.name));
+    item = CachedItem(info, d->controller->mimeTypeThumbnail(info.name));
+    return false;
+}
+
+void CameraThumbsCtrl::updateThumbInfoFromCache(const CamItemInfo& info)
+{
+    removeItemFromCache(info.url());
+    CachedItem item;
+    getThumbInfo(info, item);
 }
 
 void CameraThumbsCtrl::slotThumbInfo(const QString&, const QString& file, const CamItemInfo& info, const QImage& thumb)
@@ -202,6 +211,7 @@ void CameraThumbsCtrl::procressKDEPreview(const KFileItem& item, const QPixmap&
     {
         return;
     }
+
     QString file   = item.url().fileName();
     QString folder = item.url().toLocalFile().remove(QString("/") + file);
     QPixmap thumb;
@@ -264,8 +274,8 @@ void CameraThumbsCtrl::clearCache()
 
 void CameraThumbsCtrl::setCacheSize(int numberOfItems)
 {
-    d->cache.setMaxCost( (numberOfItems * 256 * 256 * QPixmap::defaultDepth() / 8) +
-                         (numberOfItems * 1024 * 2));
+    d->cache.setMaxCost((numberOfItems * 256 * 256 * QPixmap::defaultDepth() / 8) +
+                        (numberOfItems * 1024 * 2));
 }
 
 }  // namespace Digikam
