@@ -611,7 +611,7 @@ void FuzzySearchView::setActive(bool val)
                                "without pre-generated fingerprints.\n"
                                "Do you want to build fingerprints now?\n"
                                "Note: This process can take a while. You can run it "
-                               "any time later using 'Tools/Rebuild all Fingerprints'");
+                               "any time later using 'Tools/Rebuild all Fingerprints'.");
             int result = KMessageBox::questionYesNo(this, msg, i18n("No Fingerprints"));
 
             if (result == KMessageBox::Yes)
