@@ -41,6 +41,7 @@
 // Local includes
 
 #include "dimg.h"
+#include "dimgbuiltinfilter.h"
 
 namespace Digikam
 {
@@ -124,18 +125,23 @@ int Resize::presetLengthValue(WidthPreset preset)
         case Tiny:
             length = 480;
             break;
+
         case Small:
             length = 640;
             break;
+
         case Medium:
             length = 800;
             break;
+
         case Big:
             length = 1024;
             break;
+
         case Large:
             length = 1280;
             break;
+
         default:   // Huge
             length = 1600;
             break;
@@ -168,7 +174,8 @@ bool Resize::toolOperations()
         return false;
     }
 
-    image().resize(newSize.width(), newSize.height());
+    DImgBuiltinFilter filter(DImgBuiltinFilter::Resize, newSize);
+    applyFilter(&filter);
 
     return (savefromDImg());
 }
