@@ -42,6 +42,7 @@
 #include <kapplication.h>
 #include <kconfig.h>
 #include <kedittoolbar.h>
+#include <kde_file.h>
 #include <kglobal.h>
 #include <klocale.h>
 #include <kmenubar.h>
@@ -70,6 +71,7 @@
 #include "album.h"
 #include "drawdecoding.h"
 #include "batchtoolsmanager.h"
+#include "fileactionmngr.h"
 #include "actionthread.h"
 #include "queuepool.h"
 #include "queuelist.h"
@@ -277,6 +279,8 @@ void QueueMgrWindow::setupStatusBar()
     d->statusProgressBar = new StatusProgressBar(statusBar());
     d->statusProgressBar->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
     d->statusProgressBar->setMaximumHeight(fontMetrics().height() + 2);
+    d->statusProgressBar->setNotify(true);
+    d->statusProgressBar->setNotificationTitle(i18n("Batch Queue Manager"), KIcon("bqm-diff").pixmap(22));
     statusBar()->addWidget(d->statusProgressBar, 60);
 
     d->statusLabel = new QLabel(statusBar());
@@ -1113,7 +1117,16 @@ void QueueMgrWindow::processed(const KUrl& url, const KUrl& tmp)
 
     if (!dest.isEmpty())
     {
-        if (::rename(QFile::encodeName(tmp.toLocalFile()), QFile::encodeName(dest.toLocalFile())) != 0)
+        if (DMetadata::hasSidecar(tmp.toLocalFile()))
+        {
+            if (KDE::rename(DMetadata::sidecarPath(tmp.toLocalFile()),
+                            DMetadata::sidecarPath(dest.toLocalFile())) != 0)
+            {
+                addHistoryMessage(i18n("Failed to save sidecar file..."), DHistoryView::ErrorEntry);
+            }
+        }
+
+        if (KDE::rename(tmp.toLocalFile(), dest.toLocalFile()) != 0)
         {
             if (d->currentProcessItem)
             {
@@ -1132,17 +1145,8 @@ void QueueMgrWindow::processed(const KUrl& url, const KUrl& tmp)
 
             // -- Now copy the digiKam attributes from original file to the new file ------------
 
-            KUrl srcDirURL(QDir::cleanPath(url.directory()));
-            PAlbum* srcAlbum = AlbumManager::instance()->findPAlbum(srcDirURL);
-
-            KUrl dstDirURL(QDir::cleanPath(dest.directory()));
-            PAlbum* dstAlbum = AlbumManager::instance()->findPAlbum(dstDirURL);
-
-            if (dstAlbum && srcAlbum)
-            {
-                ImageInfo oldInfo(url.toLocalFile());
-                ScanController::instance()->scanFileDirectlyCopyAttributes(dest.toLocalFile(), oldInfo.id());
-            }
+            ImageInfo source(url.toLocalFile());
+            FileActionMngr::instance()->copyAttributes(source, dest.toLocalFile());
         }
     }
 
