@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2003-05-16
  * Description : a plugin to acquire image using flat scanner.
  *
- * Copyright (C) 2003-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2003-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -50,12 +50,13 @@
 #include "aboutdata.h"
 #include "scandialog.h"
 
-using namespace KIPIAcquireImagesPlugin;
+namespace KIPIAcquireImagesPlugin
+{
 
 K_PLUGIN_FACTORY(AcquireImagesFactory, registerPlugin<Plugin_AcquireImages>();)
 K_EXPORT_PLUGIN(AcquireImagesFactory("kipiplugin_acquireimages"))
 
-Plugin_AcquireImages::Plugin_AcquireImages(QObject* parent, const QVariantList&)
+Plugin_AcquireImages::Plugin_AcquireImages(QObject* const parent, const QVariantList&)
     : KIPI::Plugin(AcquireImagesFactory::componentData(), parent, "AcquireImages")
 {
     m_interface         = 0;
@@ -80,7 +81,7 @@ void Plugin_AcquireImages::setup(QWidget* widget)
 
     addAction(m_action_scanimages);
 
-    m_interface = dynamic_cast< KIPI::Interface* >(parent());
+    m_interface = dynamic_cast<KIPI::Interface*>(parent());
 
     if (!m_interface)
     {
@@ -121,7 +122,7 @@ void Plugin_AcquireImages::slotActivate()
 
     if (!m_scanDlg)
     {
-        m_scanDlg = new ScanDialog(m_interface, m_saneWidget, kapp->activeWindow(), new ScanDialogAboutData);
+        m_scanDlg = new ScanDialog(m_saneWidget, kapp->activeWindow(), new ScanDialogAboutData);
     }
     else
     {
@@ -146,3 +147,5 @@ KIPI::Category Plugin_AcquireImages::category(KAction* action) const
     kWarning() << "Unrecognized action for plugin category identification";
     return KIPI::ImportPlugin; // no warning from compiler, please
 }
+
+}  // namespace KIPIAcquireImagesPlugin
\ No newline at end of file
