@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2003-01-31
  * Description : a kipi plugin to slide images.
@@ -65,15 +65,17 @@ extern "C"
 #include "slideshowgl.h"
 #include "slideshowkb.h"
 #include "commoncontainer.h"
+#include "kpimageinfo.h"
 
-using namespace KIPIAdvancedSlideshowPlugin;
+namespace KIPIAdvancedSlideshowPlugin
+{
 
 K_PLUGIN_FACTORY( AdvancedSlideshowFactory, registerPlugin<Plugin_AdvancedSlideshow>(); )
 K_EXPORT_PLUGIN ( AdvancedSlideshowFactory("kipiplugin_advancedslideshow") )
 
-Plugin_AdvancedSlideshow::Plugin_AdvancedSlideshow(QObject* parent, const QVariantList &/*args*/)
-                        : KIPI::Plugin(AdvancedSlideshowFactory::componentData(),
-                                       parent, "AdvancedSlideshow")
+Plugin_AdvancedSlideshow::Plugin_AdvancedSlideshow(QObject* const parent, const QVariantList &/*args*/)
+    : KIPI::Plugin(AdvancedSlideshowFactory::componentData(),
+                   parent, "AdvancedSlideshow")
 {
     kDebug(AREA_CODE_LOADING) << "Plugin_AdvancedSlideshow plugin loaded" ;
     m_sharedData = 0;
@@ -205,9 +207,11 @@ void Plugin_AdvancedSlideshow::slotSlideShow()
     {
         fileList.append(FileAnglePair((*urlIt).toLocalFile(), 0));
         commentsList.append(QString());
-//        KIPI::ImageInfo info = m_interface->info( *urlIt );
-//        fileList.append( FileAnglePair((*urlIt).toLocalFile(), info.angle()) );
-//        commentsList.append(info.description());
+/*
+        KIPIPlugins::KPImageInfo info(m_interface, *urlIt);
+        fileList.append(FileAnglePair((*urlIt).toLocalFile(), info.orientation()));
+        commentsList.append(info.description());
+*/
     }
 
     m_urlList.clear();
@@ -274,3 +278,5 @@ KIPI::Category Plugin_AdvancedSlideshow::category(KAction* action) const
 
     return KIPI::ToolsPlugin; // no warning from compiler, please
 }
+
+}  // namespace KIPIAdvancedSlideshowPlugin
