@@ -1,13 +1,14 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2003-11-03
  * Description : painter class to draw calendar.
  *
  * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2007-2008 by Orgad Shaneh <orgads at gmail dot com>
+ * Copyright (C) 2012      by Angelo Naselli <anaselli at linux dot it>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -34,8 +35,14 @@
 
 #include <kurl.h>
 
+// Local includes
+
+#include "kpmetadata.h"
+
 class QPaintDevice;
 
+using namespace KIPIPlugins;
+
 namespace KIPICalendarPlugin
 {
 
@@ -45,10 +52,10 @@ class CalPainter : public QObject, public QPainter
 
 public:
 
-    CalPainter(QPaintDevice* pd);
+    CalPainter(QPaintDevice* const pd);
     virtual ~CalPainter();
 
-    void setImage(const KUrl& imagePath, int angle);
+    void setImage(const KUrl& imagePath, KPMetadata::ImageOrientation orientation);
     void paint(int month);
 
 Q_SIGNALS:
@@ -59,20 +66,17 @@ Q_SIGNALS:
 
 public Q_SLOTS:
 
-    void cancel()
-    {
-        cancelled_ = true;
-    };
+    void cancel();
 
 private:
 
-    bool   cancelled_;
+    bool                         cancelled_;
 
-    int    angle_;
+    KPMetadata::ImageOrientation orientation_;
 
-    QImage image_;
+    QImage                       image_;
 
-    KUrl   imagePath_;
+    KUrl                         imagePath_;
 };
 
 }  // NameSpace KIPICalendarPlugin
