@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2008-11-13
  * Description : printer thread.
@@ -33,13 +33,16 @@
 // Local includes
 
 #include "calpainter.h"
+#include "kpimageinfo.h"
+
+using namespace KIPIPlugins;
 
 namespace KIPICalendarPlugin
 {
 
 CalPrinter::CalPrinter(QPrinter* printer,
                        QMap<int, KUrl>& months,
-                       KIPI::Interface* interface,
+                       Interface* interface,
                        QObject* parent)
     : QThread(parent)
 {
@@ -64,6 +67,7 @@ void CalPrinter::run()
             this, SIGNAL(blocksFinished(int)));
 
     int currPage = 0;
+
     foreach(const int month, months_.keys())
     {
         emit pageChanged(currPage);
@@ -75,10 +79,10 @@ void CalPrinter::run()
 
         ++currPage;
 
-        int angle = interface_->info(months_.value(month)).angle();
-
-        painter_->setImage(months_.value(month), angle);
+        KPImageInfo info(months_.value(month));
+        KPMetadata::ImageOrientation orientation = info.orientation();
 
+        painter_->setImage(months_.value(month), orientation);
         painter_->paint(month);
 
         if (cancelled_)
