@@ -1,14 +1,15 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2003-11-03
  * Description : month image selection widget.
  *
  * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2006 by Tom Albers <tomalbers@kde.nl>
+ * Copyright (C) 2006      by Tom Albers <tomalbers@kde.nl>
  * Copyright (C) 2007-2008 by Orgad Shaneh <orgads at gmail dot com>
+ * Copyright (C) 2012      by Angelo Naselli <anaselli at linux dot it>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -42,9 +43,11 @@ class QPaintEvent;
 
 namespace KIPI
 {
-class Interface;
+    class Interface;
 }
 
+using namespace KIPI;
+
 namespace KIPICalendarPlugin
 {
 
@@ -54,12 +57,17 @@ class MonthWidget : public QPushButton
 
 public:
 
-    MonthWidget(KIPI::Interface* interface, QWidget* parent, int month);
+    MonthWidget(Interface* const interface, QWidget* const parent, int month);
     ~MonthWidget();
 
     KUrl imagePath() const;
     void setImage(const KUrl& url);
+    int month();
 
+Q_SIGNALS:
+  
+  void monthSelected(int);
+  
 protected:
 
     void dragEnterEvent(QDragEnterEvent* event);
@@ -70,7 +78,7 @@ protected:
 private Q_SLOTS:
 
     void gotThumbnail(const KUrl& url, const QPixmap& pix);
-
+    void monthSelected();
 private:
 
     QPixmap thumb() const;
@@ -79,11 +87,11 @@ private:
 
 private:
 
-    const QSize      thumbSize;
-    QPixmap          thumb_;
-    int              month_;
-    KUrl             imagePath_;
-    KIPI::Interface* interface_;
+    const QSize thumbSize;
+    QPixmap     thumb_;
+    int         month_;
+    KUrl        imagePath_;
+    Interface*  interface_;
 };
 
 }  // NameSpace KIPICalendarPlugin
