@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2008-09-25
  * Description : a tool to convert RAW file to DNG
  *
- * Copyright (C) 2008-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010-2011 by Jens Mueller <tschenser at gmx dot de>
  *
  * This program is free software; you can redistribute it
@@ -38,7 +38,8 @@
     DNG4PS2:             http://dng4ps2.chat.ru/index_en.html
     CORNERFIX:           http://sourceforge.net/projects/cornerfix
     ADOBE DNG CONVERTER: ftp://ftp.adobe.com/pub/adobe/photoshop/cameraraw/win/4.x
-    DNGCONVERT:          https://github.com/jmue/dngconvert    
+    DNGCONVERT:          https://github.com/jmue/dngconvert
+    MOVIE2DNG:           https://elphel.svn.sourceforge.net/svnroot/elphel/tools/Movie2DNG
 */
 
 // C ansi includes
@@ -67,18 +68,15 @@ extern "C"
 
 #include <libkdcraw/version.h>
 
-// Libkexiv2 includes
-
-#include <libkexiv2/kexiv2.h>
-
 // Local includes
 
 #include "dngwriter_p.h"
 #include "dngwriterhost.h"
+#include "kpmetadata.h"
 
 #define CHUNK 65536
 
-using namespace KExiv2Iface;
+using namespace KIPIPlugins;
 
 namespace DNGIface
 {
@@ -92,20 +90,8 @@ enum DNGBayerPattern
     FourColor
 };
 
-dng_date_time dngDateTime(QDateTime qDT)
-{
-    dng_date_time dngDT;
-    dngDT.fYear   = qDT.date().year();
-    dngDT.fMonth  = qDT.date().month();
-    dngDT.fDay    = qDT.date().day();
-    dngDT.fHour   = qDT.time().hour();
-    dngDT.fMinute = qDT.time().minute();
-    dngDT.fSecond = qDT.time().second();
-    return dngDT;
-}
-
 DNGWriter::DNGWriter()
-         : d(new DNGWriterPrivate)
+    : d(new DNGWriterPrivate)
 {
 }
 
@@ -238,9 +224,10 @@ int DNGWriter::convert()
             outputWidth  = identifyMake.outputSize.width();
         }
 
+
+#if KDCRAW_VERSION < 0x020100
         bool useFullSensorImage = false;
 
-#if KDCRAW_VERSION < 0x020001
         // disable general fullsensor image see #240750
         // seems this bug is fixed with libRaw 0.12beta4
         if ((identifyMake.make == "Canon") && 
@@ -248,15 +235,21 @@ int DNGWriter::convert()
         {
             useFullSensorImage = true;
         }
-#endif
 
-        if (!rawProcessor.extractRAWData(inputFile(), rawData, identify, 
+        if (!rawProcessor.extractRAWData(inputFile(), rawData, identify,
                                          useFullSensorImage,             // arg deprecated with KDCRAW >=0x020001
                                          0))
         {
             kDebug() << "DNGWriter: Loading RAW data failed. Aborted..." ;
             return -1;
         }
+#else
+        if (!rawProcessor.extractRAWData(inputFile(), rawData, identify, 0))
+        {
+            kDebug() << "DNGWriter: Loading RAW data failed. Aborted..." ;
+            return -1;
+        }
+#endif
 
         if (d->cancel) return -2;
 
@@ -274,7 +267,7 @@ int DNGWriter::convert()
 #if KDCRAW_VERSION < 0x020001
         kDebug() << "--- Right margin:  " << identify.rightMargin;
         kDebug() << "--- Bottom margin: " << identify.bottomMargin;
-#endif        
+#endif
         kDebug() << "--- Filter:        " << identify.filterPattern;
         kDebug() << "--- Colors:        " << identify.rawColors;
         kDebug() << "--- Black:         " << identify.blackPoint;
@@ -605,7 +598,6 @@ int DNGWriter::convert()
 
         // -------------------------------------------------------------------------------
 
-
         AutoPtr<dng_camera_profile> prof(new dng_camera_profile);
         prof->SetName(QString("%1 %2").arg(identify.make, identify.model).toAscii());
 
@@ -613,53 +605,53 @@ int DNGWriter::convert()
         dng_matrix matrix;
         switch (identify.rawColors)
         {
-        case 3:
-            {
-                dng_matrix_3by3 camXYZ;
-                camXYZ[0][0] = identify.cameraXYZMatrix[0][0];
-                camXYZ[0][1] = identify.cameraXYZMatrix[0][1];
-                camXYZ[0][2] = identify.cameraXYZMatrix[0][2];
-                camXYZ[1][0] = identify.cameraXYZMatrix[1][0];
-                camXYZ[1][1] = identify.cameraXYZMatrix[1][1];
-                camXYZ[1][2] = identify.cameraXYZMatrix[1][2];
-                camXYZ[2][0] = identify.cameraXYZMatrix[2][0];
-                camXYZ[2][1] = identify.cameraXYZMatrix[2][1];
-                camXYZ[2][2] = identify.cameraXYZMatrix[2][2];
-                if (camXYZ.MaxEntry() == 0.0)
+            case 3:
                 {
-                    kDebug() << "DNGWriter: Warning, camera XYZ Matrix is null" ;
-                    camXYZ = dng_matrix_3by3(1.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 1.0);
+                    dng_matrix_3by3 camXYZ;
+                    camXYZ[0][0] = identify.cameraXYZMatrix[0][0];
+                    camXYZ[0][1] = identify.cameraXYZMatrix[0][1];
+                    camXYZ[0][2] = identify.cameraXYZMatrix[0][2];
+                    camXYZ[1][0] = identify.cameraXYZMatrix[1][0];
+                    camXYZ[1][1] = identify.cameraXYZMatrix[1][1];
+                    camXYZ[1][2] = identify.cameraXYZMatrix[1][2];
+                    camXYZ[2][0] = identify.cameraXYZMatrix[2][0];
+                    camXYZ[2][1] = identify.cameraXYZMatrix[2][1];
+                    camXYZ[2][2] = identify.cameraXYZMatrix[2][2];
+                    if (camXYZ.MaxEntry() == 0.0)
+                    {
+                        kDebug() << "DNGWriter: Warning, camera XYZ Matrix is null" ;
+                        camXYZ = dng_matrix_3by3(1.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 1.0);
+                    }
+
+                    matrix = camXYZ;
+
+                    break;
                 }
-
-                matrix = camXYZ;
-
-                break;
-            }
-        case 4:
-            {
-                dng_matrix_4by3 camXYZ;
-                camXYZ[0][0] = identify.cameraXYZMatrix[0][0];
-                camXYZ[0][1] = identify.cameraXYZMatrix[0][1];
-                camXYZ[0][2] = identify.cameraXYZMatrix[0][2];
-                camXYZ[1][0] = identify.cameraXYZMatrix[1][0];
-                camXYZ[1][1] = identify.cameraXYZMatrix[1][1];
-                camXYZ[1][2] = identify.cameraXYZMatrix[1][2];
-                camXYZ[2][0] = identify.cameraXYZMatrix[2][0];
-                camXYZ[2][1] = identify.cameraXYZMatrix[2][1];
-                camXYZ[2][2] = identify.cameraXYZMatrix[2][2];
-                camXYZ[3][0] = identify.cameraXYZMatrix[3][0];
-                camXYZ[3][1] = identify.cameraXYZMatrix[3][1];
-                camXYZ[3][2] = identify.cameraXYZMatrix[3][2];
-                if (camXYZ.MaxEntry() == 0.0)
+            case 4:
                 {
-                    kDebug() << "DNGWriter: Warning, camera XYZ Matrix is null" ;
-                    camXYZ = dng_matrix_4by3(0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 1.0);
+                    dng_matrix_4by3 camXYZ;
+                    camXYZ[0][0] = identify.cameraXYZMatrix[0][0];
+                    camXYZ[0][1] = identify.cameraXYZMatrix[0][1];
+                    camXYZ[0][2] = identify.cameraXYZMatrix[0][2];
+                    camXYZ[1][0] = identify.cameraXYZMatrix[1][0];
+                    camXYZ[1][1] = identify.cameraXYZMatrix[1][1];
+                    camXYZ[1][2] = identify.cameraXYZMatrix[1][2];
+                    camXYZ[2][0] = identify.cameraXYZMatrix[2][0];
+                    camXYZ[2][1] = identify.cameraXYZMatrix[2][1];
+                    camXYZ[2][2] = identify.cameraXYZMatrix[2][2];
+                    camXYZ[3][0] = identify.cameraXYZMatrix[3][0];
+                    camXYZ[3][1] = identify.cameraXYZMatrix[3][1];
+                    camXYZ[3][2] = identify.cameraXYZMatrix[3][2];
+                    if (camXYZ.MaxEntry() == 0.0)
+                    {
+                        kDebug() << "DNGWriter: Warning, camera XYZ Matrix is null" ;
+                        camXYZ = dng_matrix_4by3(0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 1.0);
+                    }
+
+                    matrix = camXYZ;
+
+                    break;
                 }
-
-                matrix = camXYZ;
-
-                break;
-             }
         }
 
         prof->SetColorMatrix1((dng_matrix) matrix);
@@ -679,24 +671,25 @@ int DNGWriter::convert()
 
         kDebug() << "DNGWriter: Updating metadata to DNG Negative" ;
 
-        dng_exif *exif = negative->GetExif();
+        dng_exif* exif = negative->GetExif();
         exif->fModel.Set_ASCII(identify.model.toAscii());
         exif->fMake.Set_ASCII(identify.make.toAscii());
 
-        long int num, den;
-        long     val;
-        QString  str;
-        KExiv2   meta;
+        long int   num, den;
+        long       val;
+        QString    str;
+        KPMetadata meta;
+
         if (meta.load(inputFile()))
         {
             // Time from original shot
             dng_date_time_info dti;
-            dti.SetDateTime(dngDateTime(meta.getImageDateTime()));
+            dti.SetDateTime(d->dngDateTime(meta.getImageDateTime()));
             exif->fDateTimeOriginal = dti;
 
-            dti.SetDateTime(dngDateTime(meta.getDigitizationDateTime(true)));
+            dti.SetDateTime(d->dngDateTime(meta.getDigitizationDateTime(true)));
             exif->fDateTimeDigitized = dti;
- 
+
             negative->UpdateDateTime(dti);
 
             // String Tags
@@ -986,7 +979,7 @@ int DNGWriter::convert()
 
             str = meta.getExifTagString("Exif.OlympusEq.LensSerialNumber");
             if (str.length()) exif->fLensSerialNumber.Set_ASCII(str.trimmed().toAscii());
-            
+
             str = meta.getExifTagString("Exif.OlympusEq.LensModel");
             if (str.length()) exif->fLensName.Set_ASCII(str.trimmed().toAscii());
 
@@ -994,7 +987,7 @@ int DNGWriter::convert()
             if (meta.getExifTagLong("Exif.OlympusEq.MaxFocalLength", val))             exif->fLensInfo[1]              = dng_urational(val, 1);
 
             // Panasonic Makernotes
-            
+
             str = meta.getExifTagString("Exif.Panasonic.LensType");
             if (str.length()) exif->fLensName.Set_ASCII(str.trimmed().toAscii());
 
@@ -1010,8 +1003,8 @@ int DNGWriter::convert()
 
             str = meta.getExifTagString("Exif.Sony2.LensID");
             if (str.length()) exif->fLensName.Set_ASCII(str.trimmed().toAscii());
-            
-            // 
+
+            // -------------------------------------------
 
             if ((exif->fLensName.IsEmpty()) && 
                 (exif->fLensInfo[0].As_real64() > 0) &&
@@ -1027,13 +1020,13 @@ int DNGWriter::convert()
                     stream << QString("-%1").arg(dval, 0, 'f', 1);
                 }
                 stream << " mm";
-                
+
                 if (exif->fLensInfo[2].As_real64() > 0)
                 {
                     dval = (double)exif->fLensInfo[2].n / (double)exif->fLensInfo[2].d;
                     stream << QString(" 1/%1").arg(dval, 0, 'f', 1);
                 }
-                
+
                 if ((exif->fLensInfo[3].As_real64() > 0) &&
                     (exif->fLensInfo[2].As_real64() != exif->fLensInfo[3].As_real64()))
                 {
@@ -1043,7 +1036,7 @@ int DNGWriter::convert()
 
                 exif->fLensName.Set_ASCII(lensName.toAscii());
             }
-            
+
             // Markernote backup.
 
             QByteArray mkrnts = meta.getExifTagData("Exif.Photo.MakerNote");
@@ -1068,7 +1061,7 @@ int DNGWriter::convert()
                 QString mknByteOrder = meta.getExifTagString("Exif.MakerNote.ByteOrder");
 
                 if ((meta.getExifTagLong("Exif.MakerNote.Offset", mknOffset)) && !mknByteOrder.isEmpty())
-                {                   
+                {
                     dng_memory_stream streamPriv(memalloc);
                     streamPriv.SetBigEndian();
 
@@ -1283,18 +1276,23 @@ int DNGWriter::convert()
 
         // -----------------------------------------------------------------------------------------
         // Metadata makernote cleanup using Exiv2 for some RAW file types
-        // See B.K.O #204437 and #210371
+        // See B.K.O #204437 and #210371, and write XMP Sidecar if necessary
 
-        if (inputInfo.suffix().toUpper() == QString("ORF"))
+        if (meta.load(dngFilePath))
         {
-            kDebug() << "DNGWriter: cleanup makernotes using Exiv2" ;
-
-            if (meta.load(dngFilePath))
+            if (inputInfo.suffix().toUpper() == QString("ORF"))
             {
+                kDebug() << "DNGWriter: cleanup makernotes using Exiv2" ;
+
                 meta.setWriteRawFiles(true);
                 meta.removeExifTag("Exif.OlympusIp.BlackLevel", false);
-                meta.applyChanges();
             }
+            else
+            {
+                // Don't touch DNG file and create XMP sidecar depending of KIPI host application settings.
+                meta.setWriteRawFiles(false);
+            }
+            meta.applyChanges();
         }
 
         // -----------------------------------------------------------------------------------------
