@@ -1,13 +1,14 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2009-11-13
  * Description : a plugin to blend bracketed images.
  *
  * Copyright (C) 2009-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2011 by Johannes Wienke <languitar at semipol dot de>
+ * Copyright (C) 2012 by Benjamin Girault <benjamin dot girault at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -56,7 +57,7 @@
 // Local includes
 
 #include "kpwriteimage.h"
-#include "pluginsversion.h"
+#include "kpversion.h"
 
 namespace KIPIExpoBlendingPlugin
 {
@@ -81,6 +82,7 @@ public:
             bool                align;
             KUrl::List          urls;
             KUrl                outputUrl;
+            QString             binaryPath;
             Action              action;
             RawDecodingSettings rawDecodingSettings;
             EnfuseSettings      enfuseSettings;
@@ -127,7 +129,7 @@ public:
     }
 };
 
-ActionThread::ActionThread(QObject* parent)
+ActionThread::ActionThread(QObject* const parent)
             : QThread(parent), d(new ActionThreadPriv)
 {
     qRegisterMetaType<ActionData>();
@@ -153,9 +155,9 @@ ActionThread::~ActionThread()
     delete d;
 }
 
-void ActionThread::setEnfuseVersion(const QString& version)
+void ActionThread::setEnfuseVersion(const double version)
 {
-    d->enfuseVersion4x = (version.toDouble() >= 4.0);
+    d->enfuseVersion4x = (version >= 4.0);
 }
 
 void ActionThread::cleanUpResultFiles()
@@ -201,39 +203,44 @@ void ActionThread::loadProcessed(const KUrl& url)
     d->condVar.wakeAll();
 }
 
-void ActionThread::preProcessFiles(const KUrl::List& urlList)
+void ActionThread::preProcessFiles(const KUrl::List& urlList, const QString& alignPath)
 {
     ActionThreadPriv::Task* t = new ActionThreadPriv::Task;
     t->action                 = PREPROCESSING;
     t->urls                   = urlList;
     t->rawDecodingSettings    = d->rawDecodingSettings;
     t->align                  = d->align;
+    t->binaryPath             = alignPath;
 
     QMutexLocker lock(&d->mutex);
     d->todo << t;
     d->condVar.wakeAll();
 }
 
-void ActionThread::enfusePreview(const KUrl::List& alignedUrls, const KUrl& outputUrl, const EnfuseSettings& settings)
+void ActionThread::enfusePreview(const KUrl::List& alignedUrls, const KUrl& outputUrl,
+                                 const EnfuseSettings& settings, const QString& enfusePath)
 {
     ActionThreadPriv::Task* t = new ActionThreadPriv::Task;
     t->action                 = ENFUSEPREVIEW;
     t->urls                   = alignedUrls;
     t->outputUrl              = outputUrl;
     t->enfuseSettings         = settings;
+    t->binaryPath             = enfusePath;
 
     QMutexLocker lock(&d->mutex);
     d->todo << t;
     d->condVar.wakeAll();
 }
 
-void ActionThread::enfuseFinal(const KUrl::List& alignedUrls, const KUrl& outputUrl, const EnfuseSettings& settings)
+void ActionThread::enfuseFinal(const KUrl::List& alignedUrls, const KUrl& outputUrl,
+                               const EnfuseSettings& settings, const QString& enfusePath)
 {
     ActionThreadPriv::Task* t = new ActionThreadPriv::Task;
     t->action                 = ENFUSEFINAL;
     t->urls                   = alignedUrls;
     t->outputUrl              = outputUrl;
     t->enfuseSettings         = settings;
+    t->binaryPath             = enfusePath;
 
     QMutexLocker lock(&d->mutex);
     d->todo << t;
@@ -314,7 +321,7 @@ void ActionThread::run()
                     ItemUrlsMap preProcessedUrlsMap;
                     QString     errors;
 
-                    bool result  = startPreProcessing(t->urls, preProcessedUrlsMap, t->align, t->rawDecodingSettings, errors);
+                    bool result  = startPreProcessing(t->urls, preProcessedUrlsMap, t->align, t->rawDecodingSettings, t->binaryPath, errors);
 
                     ActionData ad2;
                     ad2.action              = PREPROCESSING;
@@ -340,7 +347,7 @@ void ActionThread::run()
                     // rotate image
                     if (result)
                     {
-                        KExiv2 meta(t->urls[0].toLocalFile());
+                        KPMetadata meta(t->urls[0].toLocalFile());
                         meta.rotateExifQImage(image, meta.getImageOrientation());
                     }
 
@@ -365,18 +372,18 @@ void ActionThread::run()
                     QString errors;
                     KUrl    destUrl         = t->outputUrl;
                     EnfuseSettings settings = t->enfuseSettings;
-                    settings.outputFormat   = SaveSettingsWidget::OUTPUT_JPEG;    // JPEG for preview: fast and small.
-                    bool result             = startEnfuse(t->urls, destUrl, settings, errors);
+                    settings.outputFormat   = KPSaveSettingsWidget::OUTPUT_JPEG;    // JPEG for preview: fast and small.
+                    bool result             = startEnfuse(t->urls, destUrl, settings, t->binaryPath, errors);
 
                     kDebug() << "Preview result was: " << result;
 
                     // preserve exif information for auto rotation
                     if (result)
                     {
-                        KExiv2 metai(t->urls[0].toLocalFile());
-                        KExiv2 metao(destUrl.toLocalFile());
-                        metao.setImageOrientation(metai.getImageOrientation());
-                        metao.applyChanges();
+                        KPMetadata metaIn(t->urls[0].toLocalFile());
+                        KPMetadata metaOut(destUrl.toLocalFile());
+                        metaOut.setImageOrientation(metaIn.getImageOrientation());
+                        metaOut.applyChanges();
                     }
 
                     // To be cleaned in destructor.
@@ -407,15 +414,15 @@ void ActionThread::run()
                     bool    result  = false;
                     QString errors;
 
-                    result = startEnfuse(t->urls, destUrl, t->enfuseSettings, errors);
+                    result = startEnfuse(t->urls, destUrl, t->enfuseSettings, t->binaryPath, errors);
 
                     // We will take first image metadata from stack to restore Exif, Iptc, and Xmp.
-                    KExiv2 meta;
+                    KPMetadata meta;
                     meta.load(t->urls[0].toLocalFile());
                     meta.setXmpTagString("Xmp.kipi.EnfuseInputFiles", t->enfuseSettings.inputImagesList(), false);
                     meta.setXmpTagString("Xmp.kipi.EnfuseSettings", t->enfuseSettings.asCommentString().replace('\n', " ; "), false);
                     meta.setImageDateTime(QDateTime::currentDateTime());
-                    if (t->enfuseSettings.outputFormat != SaveSettingsWidget::OUTPUT_JPEG)
+                    if (t->enfuseSettings.outputFormat != KPSaveSettingsWidget::OUTPUT_JPEG)
                     {
                         QImage img;
                         if (img.load(destUrl.toLocalFile()))
@@ -441,6 +448,7 @@ void ActionThread::run()
                 default:
                 {
                     qCritical() << "Unknown action specified" << endl;
+                    break;
                 }
             }
         }
@@ -451,7 +459,7 @@ void ActionThread::run()
 
 bool ActionThread::startPreProcessing(const KUrl::List& inUrls, ItemUrlsMap& preProcessedUrlsMap,
                                       bool align, const RawDecodingSettings& settings,
-                                      QString& errors)
+                                      const QString& alignPath, QString& errors)
 {
     QString prefix = KStandardDirs::locateLocal("tmp", QString("kipi-expoblending-preprocessing-tmp-") +
                                                        QString::number(QDateTime::currentDateTime().toTime_t()));
@@ -477,7 +485,7 @@ bool ActionThread::startPreProcessing(const KUrl::List& inUrls, ItemUrlsMap& pre
 
         KUrl url = inUrls.at(i);
 
-        if (isRawFile(url.toLocalFile()))
+        if (KPMetadata::isRawFile(url.toLocalFile()))
         {
             KUrl preprocessedUrl, previewUrl;
 
@@ -540,7 +548,7 @@ bool ActionThread::startPreProcessing(const KUrl::List& inUrls, ItemUrlsMap& pre
         d->alignProcess->setOutputChannelMode(KProcess::MergedChannels);
 
         QStringList args;
-        args << "align_image_stack";
+        args << alignPath;
         args << "-v";
         args << "-a";
         args << "aligned";
@@ -621,14 +629,14 @@ bool ActionThread::computePreview(const KUrl& inUrl, KUrl& outUrl)
     if (img.load(inUrl.toLocalFile()))
     {
         QImage preview = img.scaled(1280, 1024, Qt::KeepAspectRatio);
-        bool saved = preview.save(outUrl.toLocalFile(), "JPEG");
+        bool saved     = preview.save(outUrl.toLocalFile(), "JPEG");
         // save exif information also to preview image for auto rotation
         if (saved)
         {
-            KExiv2 metai(inUrl.toLocalFile());
-            KExiv2 metao(outUrl.toLocalFile());
-            metao.setImageOrientation(metai.getImageOrientation());
-            metao.applyChanges();
+            KPMetadata metaIn(inUrl.toLocalFile());
+            KPMetadata metaOut(outUrl.toLocalFile());
+            metaOut.setImageOrientation(metaIn.getImageOrientation());
+            metaOut.applyChanges();
         }
         kDebug() << "Preview Image url: " << outUrl << ", saved: " << saved;
         return saved;
@@ -672,14 +680,14 @@ bool ActionThread::convertRaw(const KUrl& inUrl, KUrl& outUrl, const RawDecoding
             sptr += 6;
         }
 
-        KExiv2 meta;
+        KPMetadata meta;
         meta.load(inUrl.toLocalFile());
         meta.setImageProgramId(QString("Kipi-plugins"), QString(kipiplugins_version));
         meta.setImageDimensions(QSize(width, height));
         meta.setExifTagString("Exif.Image.DocumentName", inUrl.fileName());
         meta.setXmpTagString("Xmp.tiff.Make",  meta.getExifTagString("Exif.Image.Make"));
         meta.setXmpTagString("Xmp.tiff.Model", meta.getExifTagString("Exif.Image.Model"));
-        meta.setImageOrientation(KExiv2Iface::KExiv2::ORIENTATION_NORMAL);
+        meta.setImageOrientation(KPMetadata::ORIENTATION_NORMAL);
 
         QByteArray prof = KPWriteImage::getICCProfilFromFile(settings.outputColorSpace);
 
@@ -703,23 +711,12 @@ bool ActionThread::convertRaw(const KUrl& inUrl, KUrl& outUrl, const RawDecoding
     return true;
 }
 
-bool ActionThread::isRawFile(const KUrl& url)
-{
-    QString rawFilesExt(KDcraw::rawFiles());
-
-    QFileInfo fileInfo(url.toLocalFile());
-    if (rawFilesExt.toUpper().contains(fileInfo.suffix().toUpper()))
-        return true;
-
-    return false;
-}
-
 bool ActionThread::startEnfuse(const KUrl::List& inUrls, KUrl& outUrl,
                                const EnfuseSettings& settings,
-                               QString& errors)
+                               const QString& enfusePath, QString& errors)
 {
     QString comp;
-    QString ext = SaveSettingsWidget::extensionForFormat(settings.outputFormat);
+    QString ext = KPSaveSettingsWidget::extensionForFormat(settings.outputFormat);
 
     if (ext == QString(".tif"))
         comp = QString("--compression=DEFLATE");
@@ -730,7 +727,7 @@ bool ActionThread::startEnfuse(const KUrl::List& inUrls, KUrl& outUrl,
     d->enfuseProcess->clearProgram();
     d->enfuseProcess->setOutputChannelMode(KProcess::MergedChannels);
     QStringList args;
-    args << "enfuse";
+    args << enfusePath;
 
     if (!settings.autoLevels)
     {
@@ -801,7 +798,7 @@ bool ActionThread::startEnfuse(const KUrl::List& inUrls, KUrl& outUrl,
     return false;
 }
 
-QString ActionThread::getProcessError(KProcess* proc) const
+QString ActionThread::getProcessError(KProcess* const proc) const
 {
     if (!proc) return QString();
 
@@ -833,7 +830,7 @@ QString ActionThread::getProcessError(KProcess* proc) const
  */
 float ActionThread::getAverageSceneLuminance(const KUrl& url)
 {
-    KExiv2 meta;
+    KPMetadata meta;
     meta.load(url.toLocalFile());
     if (!meta.hasExif())
         return -1;
@@ -960,7 +957,7 @@ float ActionThread::getAverageSceneLuminance(const KUrl& url)
     return -1.0;
 }
 
-bool ActionThread::getXmpRational(const char* xmpTagName, long& num, long& den, KExiv2& meta)
+bool ActionThread::getXmpRational(const char* xmpTagName, long& num, long& den, KPMetadata& meta)
 {
     QVariant rationals = meta.getXmpTagVariant(xmpTagName);
 
