@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2008-12-26
  * Description : a kipi plugin to import/export images to Facebook web service
@@ -30,7 +30,6 @@
 #include <QGroupBox>
 #include <QRadioButton>
 #include <QButtonGroup>
-#include <QProgressBar>
 #include <QGridLayout>
 #include <QHBoxLayout>
 #include <QVBoxLayout>
@@ -46,15 +45,17 @@
 
 #include <libkipi/interface.h>
 #include <libkipi/uploadwidget.h>
+#include <libkipi/imagecollection.h>
 
 // Local includes
 
-#include "imageslist.h"
+#include "kpimageslist.h"
+#include "kpprogresswidget.h"
 
 namespace KIPIFacebookPlugin
 {
 
-FbWidget::FbWidget(QWidget* parent, KIPI::Interface *iface, bool import)
+FbWidget::FbWidget(QWidget* const parent, KIPI::Interface* const iface, bool import)
     : QWidget(parent)
 {
     setObjectName("FbWidget");
@@ -63,8 +64,8 @@ FbWidget::FbWidget(QWidget* parent, KIPI::Interface *iface, bool import)
 
     // -------------------------------------------------------------------
 
-    m_imgList = new KIPIPlugins::ImagesList(iface, this);
-    m_imgList->setControlButtonsPlacement(KIPIPlugins::ImagesList::ControlButtonsBelow);
+    m_imgList = new KIPIPlugins::KPImagesList(this);
+    m_imgList->setControlButtonsPlacement(KIPIPlugins::KPImagesList::ControlButtonsBelow);
     m_imgList->setAllowRAW(true);
     m_imgList->loadImagesFromCurrentSelection();
     m_imgList->listView()->setWhatsThis(i18n("This is the list of images to upload to your Facebook account."));
@@ -199,7 +200,7 @@ FbWidget::FbWidget(QWidget* parent, KIPI::Interface *iface, bool import)
     optionsBoxLayout->setSpacing(KDialog::spacingHint());
     optionsBoxLayout->setMargin(KDialog::spacingHint());
 
-    m_progressBar = new QProgressBar(settingsBox);
+    m_progressBar = new KIPIPlugins::KPProgressWidget(settingsBox);
     m_progressBar->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
     m_progressBar->hide();
 
@@ -269,12 +270,12 @@ FbWidget::~FbWidget()
 {
 }
 
-KIPIPlugins::ImagesList* FbWidget::imagesList() const
+KIPIPlugins::KPImagesList* FbWidget::imagesList() const
 {
     return m_imgList;
 }
 
-QProgressBar* FbWidget::progressBar() const
+KIPIPlugins::KPProgressWidget* FbWidget::progressBar() const
 {
     return m_progressBar;
 }
