@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2005-17-06
  * Description : a kipi plugin to export images to Flickr web service
  *
  * Copyright (C) 2005-2008 by Vardhman Jain <vardhman at gmail dot com>
- * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -33,16 +33,15 @@
 
 // KDE includes
 
-#include <kdialog.h>
-
-// Local includes
-
-#include "comboboxintermediate.h"
-
 // LibKIPI includes
 
 #include <libkipi/interface.h>
 
+// Local includes
+
+#include "kptooldialog.h"
+#include "comboboxintermediate.h"
+
 class QProgressDialog;
 class QPushButton;
 class QSpinBox;
@@ -55,20 +54,22 @@ class KComboBox;
 
 namespace KIPI
 {
-class Interface;
+    class Interface;
 }
 
 namespace KIPIPlugins
 {
-class KPAboutData;
-class FlickrList;
+    class KPAboutData;
 }
 
 namespace KWallet
 {
-class Wallet;
+    class Wallet;
 }
 
+using namespace KIPI;
+using namespace KIPIPlugins;
+
 namespace KIPIFlickrExportPlugin
 {
 
@@ -80,14 +81,16 @@ class GPhoto;
 class GAlbum;
 //class GAlbumViewItem;
 
-class FlickrWindow : public KDialog
+using namespace KIPI;
+using namespace KIPIPlugins;
+
+class FlickrWindow : public KPToolDialog
 {
     Q_OBJECT
 
 public:
 
-    FlickrWindow(KIPI::Interface* interface, const QString& tmpFolder,
-                 QWidget* parent, const QString& serviceName);
+    FlickrWindow(const QString& tmpFolder, QWidget* const parent, const QString& serviceName);
     ~FlickrWindow();
 
     /**
@@ -117,9 +120,8 @@ private Q_SLOTS:
     void slotAddPhotoFailed(const QString& msg);
     void slotAddPhotoSetSucceeded();
     void slotListPhotoSetsFailed(const QString& msg);
-    void slotAddPhotoCancel();
+    void slotAddPhotoCancelAndClose();
     void slotAuthCancel();
-    void slotHelp();
     void slotClose();
     void slotUser1();
     void slotImageListChanged();
@@ -158,7 +160,7 @@ private:
     ComboBoxIntermediate*                  m_contentTypeComboBox;
     ComboBoxIntermediate*                  m_safetyLevelComboBox;
 
-    //    QHash<int, GAlbumViewItem>             m_albumDict;
+//  QHash<int, GAlbumViewItem>             m_albumDict;
 
     QString                                m_token;
     QString                                m_username;
@@ -168,12 +170,11 @@ private:
 
     QLabel*                                m_userNameDisplayLabel;
 
-    QProgressDialog*                       m_progressDlg;
     QProgressDialog*                       m_authProgressDlg;
 
     QList< QPair<KUrl, FPhotoInfo> >       m_uploadQueue;
 
-    //    KWallet::Wallet                       *m_wallet;
+//  KWallet::Wallet*                       m_wallet;
     KHTMLPart*                             m_photoView;
 
     KLineEdit*                             m_tagsLineEdit;
@@ -181,10 +182,7 @@ private:
     FlickrWidget*                          m_widget;
     FlickrTalker*                          m_talker;
 
-    KIPI::Interface*                       m_interface;
-
-    KIPIPlugins::KPAboutData*              m_about;
-    KIPIFlickrExportPlugin::FlickrList*    m_imglst;
+    FlickrList*                            m_imglst;
 };
 
 } // namespace KIPIFlickrExportPlugin
