@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2006-05-16
  * Description : A plugin to create KML files to present images with coordinates.
  *
- * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -49,28 +49,26 @@
 #include <libkipi/imagecollection.h>
 #include <libkipi/interface.h>
 
-// LibKExiv2 includes
-
-#include <libkexiv2/version.h>
-#include <libkexiv2/kexiv2.h>
-
 // Local includes
 
 #include "kmlexport.h"
 #include "kmlexportconfig.h"
 
+namespace KIPIKMLExportPlugin
+{
+
 K_PLUGIN_FACTORY( KMLExportFactory, registerPlugin<Plugin_KMLExport>(); )
 K_EXPORT_PLUGIN ( KMLExportFactory("kipiplugin_kmlexport") )
 
-Plugin_KMLExport::Plugin_KMLExport(QObject* parent, const QVariantList&)
-    : KIPI::Plugin( KMLExportFactory::componentData(), parent, "KMLExport")
+Plugin_KMLExport::Plugin_KMLExport(QObject* const parent, const QVariantList&)
+    : Plugin( KMLExportFactory::componentData(), parent, "KMLExport")
 {
     kDebug(AREA_CODE_LOADING) << "Plugin_KMLExport plugin loaded" ;
 }
 
-void Plugin_KMLExport::setup( QWidget* widget )
+void Plugin_KMLExport::setup(QWidget* widget)
 {
-    KIPI::Plugin::setup( widget );
+    Plugin::setup( widget );
 
     m_actionKMLExport = actionCollection()->addAction("kmlexport");
     m_actionKMLExport->setText(i18n("Export to KML..."));
@@ -81,7 +79,7 @@ void Plugin_KMLExport::setup( QWidget* widget )
 
     addAction( m_actionKMLExport );
 
-    m_interface = dynamic_cast<KIPI::Interface*>( parent() );
+    m_interface = dynamic_cast<Interface*>( parent() );
 
     if ( !m_interface )
     {
@@ -92,7 +90,7 @@ void Plugin_KMLExport::setup( QWidget* widget )
 
 void Plugin_KMLExport::slotKMLExport()
 {
-    KIPI::ImageCollection selection = m_interface->currentSelection();
+    ImageCollection selection = m_interface->currentSelection();
 
     if ( !selection.isValid() )
     {
@@ -100,7 +98,7 @@ void Plugin_KMLExport::slotKMLExport()
     }
     else
     {
-        KIPIKMLExportPlugin::KMLExportConfig* kmlExportConfigGui = new KIPIKMLExportPlugin::KMLExportConfig(kapp->activeWindow());
+        KMLExportConfig* kmlExportConfigGui = new KMLExportConfig(kapp->activeWindow());
 
         connect(kmlExportConfigGui, SIGNAL(okButtonClicked()),
                 this, SLOT(slotKMLGenerate()));
@@ -111,21 +109,23 @@ void Plugin_KMLExport::slotKMLExport()
 
 void Plugin_KMLExport::slotKMLGenerate()
 {
-    KIPI::ImageCollection selection = m_interface->currentSelection();
-    KIPIKMLExportPlugin::kmlExport myExport(m_interface);
+    ImageCollection selection = m_interface->currentSelection();
+    KmlExport myExport(m_interface);
     if(!myExport.getConfig())
         return;
 
     myExport.generate();
 }
 
-KIPI::Category Plugin_KMLExport::category( KAction* action ) const
+Category Plugin_KMLExport::category(KAction* action) const
 {
     if ( action == m_actionKMLExport )
     {
-       return KIPI::ExportPlugin;
+       return ExportPlugin;
     }
 
     kWarning() << "Unrecognized action for plugin category identification" ;
-    return KIPI::ImagesPlugin; // no warning from compiler, please
+    return ExportPlugin; // no warning from compiler, please
 }
+
+} // namespace KIPIKMLExportPlugin
