@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2006-10-13
  * Description : IPTC origin settings page.
  *
- * Copyright (C) 2006-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -47,8 +47,6 @@
 
 // LibKExiv2 includes
 
-#include <libkexiv2/version.h>
-#include <libkexiv2/kexiv2.h>
 #include <libkexiv2/countryselector.h>
 
 // LibKDcraw includes
@@ -59,9 +57,10 @@
 
 #include "metadatacheckbox.h"
 #include "multivaluesedit.h"
+#include "kpmetadata.h"
 
+using namespace KIPIPlugins;
 using namespace KDcrawIface;
-using namespace KExiv2Iface;
 
 namespace KIPIMetadataEditPlugin
 {
@@ -124,7 +123,7 @@ public:
     CountrySelector*               countryCB;
 };
 
-IPTCOrigin::IPTCOrigin(QWidget* parent)
+IPTCOrigin::IPTCOrigin(QWidget* const parent)
     : QWidget(parent), d(new IPTCOriginPriv)
 {
     QGridLayout* grid = new QGridLayout(this);
@@ -380,12 +379,12 @@ void IPTCOrigin::slotSetTodayDigitalized()
     d->timeDigitalizedSel->setTime(QTime::currentTime());
 }
 
-bool IPTCOrigin::syncHOSTDateIsChecked()
+bool IPTCOrigin::syncHOSTDateIsChecked() const
 {
     return d->syncHOSTDateCheck->isChecked();
 }
 
-bool IPTCOrigin::syncEXIFDateIsChecked()
+bool IPTCOrigin::syncEXIFDateIsChecked() const
 {
     return d->syncEXIFDateCheck->isChecked();
 }
@@ -400,7 +399,7 @@ void IPTCOrigin::setCheckedSyncEXIFDate(bool c)
     d->syncEXIFDateCheck->setChecked(c);
 }
 
-QDateTime IPTCOrigin::getIPTCCreationDate()
+QDateTime IPTCOrigin::getIPTCCreationDate() const
 {
     return QDateTime(d->dateCreatedSel->date(), d->timeCreatedSel->time());
 }
@@ -408,8 +407,8 @@ QDateTime IPTCOrigin::getIPTCCreationDate()
 void IPTCOrigin::readMetadata(QByteArray& iptcData)
 {
     blockSignals(true);
-    KExiv2 exiv2Iface;
-    exiv2Iface.setIptc(iptcData);
+    KPMetadata meta;
+    meta.setIptc(iptcData);
 
     QString     data;
     QStringList code, list;
@@ -417,8 +416,8 @@ void IPTCOrigin::readMetadata(QByteArray& iptcData)
     QTime       time;
     QString     dateStr, timeStr;
 
-    dateStr = exiv2Iface.getIptcTagString("Iptc.Application2.DateCreated", false);
-    timeStr = exiv2Iface.getIptcTagString("Iptc.Application2.TimeCreated", false);
+    dateStr = meta.getIptcTagString("Iptc.Application2.DateCreated", false);
+    timeStr = meta.getIptcTagString("Iptc.Application2.TimeCreated", false);
 
     d->dateCreatedSel->setDate(QDate::currentDate());
     d->dateCreatedCheck->setChecked(false);
@@ -448,8 +447,8 @@ void IPTCOrigin::readMetadata(QByteArray& iptcData)
     }
     d->timeCreatedSel->setEnabled(d->timeCreatedCheck->isChecked());
 
-    dateStr = exiv2Iface.getIptcTagString("Iptc.Application2.DigitizationDate", false);
-    timeStr = exiv2Iface.getIptcTagString("Iptc.Application2.DigitizationTime", false);
+    dateStr = meta.getIptcTagString("Iptc.Application2.DigitizationDate", false);
+    timeStr = meta.getIptcTagString("Iptc.Application2.DigitizationTime", false);
 
     d->dateDigitalizedSel->setDate(QDate::currentDate());
     d->dateDigitalizedCheck->setChecked(false);
@@ -478,7 +477,7 @@ void IPTCOrigin::readMetadata(QByteArray& iptcData)
     d->timeDigitalizedSel->setEnabled(d->timeDigitalizedCheck->isChecked());
 
 
-    code = exiv2Iface.getIptcTagsStringList("Iptc.Application2.LocationCode", false);
+    code = meta.getIptcTagsStringList("Iptc.Application2.LocationCode", false);
     for (QStringList::Iterator it = code.begin(); it != code.end(); ++it)
     {
         QStringList data = d->locationEdit->getData();
@@ -498,7 +497,7 @@ void IPTCOrigin::readMetadata(QByteArray& iptcData)
 
     d->cityEdit->clear();
     d->cityCheck->setChecked(false);
-    data = exiv2Iface.getIptcTagString("Iptc.Application2.City", false);
+    data = meta.getIptcTagString("Iptc.Application2.City", false);
     if (!data.isNull())
     {
         d->cityEdit->setText(data);
@@ -508,7 +507,7 @@ void IPTCOrigin::readMetadata(QByteArray& iptcData)
 
     d->sublocationEdit->clear();
     d->sublocationCheck->setChecked(false);
-    data = exiv2Iface.getIptcTagString("Iptc.Application2.SubLocation", false);
+    data = meta.getIptcTagString("Iptc.Application2.SubLocation", false);
     if (!data.isNull())
     {
         d->sublocationEdit->setText(data);
@@ -518,7 +517,7 @@ void IPTCOrigin::readMetadata(QByteArray& iptcData)
 
     d->provinceEdit->clear();
     d->provinceCheck->setChecked(false);
-    data = exiv2Iface.getIptcTagString("Iptc.Application2.ProvinceState", false);
+    data = meta.getIptcTagString("Iptc.Application2.ProvinceState", false);
     if (!data.isNull())
     {
         d->provinceEdit->setText(data);
@@ -528,7 +527,7 @@ void IPTCOrigin::readMetadata(QByteArray& iptcData)
 
     d->countryCB->setCurrentIndex(0);
     d->countryCheck->setChecked(false);
-    data = exiv2Iface.getIptcTagString("Iptc.Application2.CountryCode", false);
+    data = meta.getIptcTagString("Iptc.Application2.CountryCode", false);
     if (!data.isNull())
     {
         int item = -1;
@@ -551,40 +550,40 @@ void IPTCOrigin::readMetadata(QByteArray& iptcData)
 
 void IPTCOrigin::applyMetadata(QByteArray& exifData, QByteArray& iptcData)
 {
-    KExiv2 exiv2Iface;
-    exiv2Iface.setExif(exifData);
-    exiv2Iface.setIptc(iptcData);
+    KPMetadata meta;
+    meta.setExif(exifData);
+    meta.setIptc(iptcData);
 
     if (d->dateCreatedCheck->isChecked())
     {
-        exiv2Iface.setIptcTagString("Iptc.Application2.DateCreated",
+        meta.setIptcTagString("Iptc.Application2.DateCreated",
                                     getIPTCCreationDate().toString(Qt::ISODate));
         if (syncEXIFDateIsChecked())
         {
-            exiv2Iface.setExifTagString("Exif.Image.DateTime",
+            meta.setExifTagString("Exif.Image.DateTime",
                     getIPTCCreationDate().toString(QString("yyyy:MM:dd hh:mm:ss")).toAscii());
         }
     }
     else
-        exiv2Iface.removeIptcTag("Iptc.Application2.DateCreated");
+        meta.removeIptcTag("Iptc.Application2.DateCreated");
 
     if (d->dateDigitalizedCheck->isChecked())
-        exiv2Iface.setIptcTagString("Iptc.Application2.DigitizationDate",
+        meta.setIptcTagString("Iptc.Application2.DigitizationDate",
                                     d->dateDigitalizedSel->date().toString(Qt::ISODate));
     else
-        exiv2Iface.removeIptcTag("Iptc.Application2.DigitizationDate");
+        meta.removeIptcTag("Iptc.Application2.DigitizationDate");
 
     if (d->timeCreatedCheck->isChecked())
-        exiv2Iface.setIptcTagString("Iptc.Application2.TimeCreated",
+        meta.setIptcTagString("Iptc.Application2.TimeCreated",
                                     d->timeCreatedSel->time().toString(Qt::ISODate));
     else
-        exiv2Iface.removeIptcTag("Iptc.Application2.TimeCreated");
+        meta.removeIptcTag("Iptc.Application2.TimeCreated");
 
     if (d->timeDigitalizedCheck->isChecked())
-        exiv2Iface.setIptcTagString("Iptc.Application2.DigitizationTime",
+        meta.setIptcTagString("Iptc.Application2.DigitizationTime",
                                     d->timeDigitalizedSel->time().toString(Qt::ISODate));
     else
-        exiv2Iface.removeIptcTag("Iptc.Application2.DigitizationTime");
+        meta.removeIptcTag("Iptc.Application2.DigitizationTime");
 
     QStringList oldList, newList;
     if (d->locationEdit->getValues(oldList, newList))
@@ -603,50 +602,50 @@ void IPTCOrigin::applyMetadata(QByteArray& exifData, QByteArray& iptcData)
             newName.append((*it2).mid(6));
         }
 
-        exiv2Iface.setIptcTagsStringList("Iptc.Application2.LocationCode", 3, oldCode, newCode);
-        exiv2Iface.setIptcTagsStringList("Iptc.Application2.LocationName", 64, oldName, newName);
+        meta.setIptcTagsStringList("Iptc.Application2.LocationCode", 3, oldCode, newCode);
+        meta.setIptcTagsStringList("Iptc.Application2.LocationName", 64, oldName, newName);
     }
     else
     {
-        exiv2Iface.removeIptcTag("Iptc.Application2.LocationCode");
-        exiv2Iface.removeIptcTag("Iptc.Application2.LocationName");
+        meta.removeIptcTag("Iptc.Application2.LocationCode");
+        meta.removeIptcTag("Iptc.Application2.LocationName");
     }
 
     if (d->cityCheck->isChecked())
-        exiv2Iface.setIptcTagString("Iptc.Application2.City", d->cityEdit->text());
+        meta.setIptcTagString("Iptc.Application2.City", d->cityEdit->text());
     else
-        exiv2Iface.removeIptcTag("Iptc.Application2.City");
+        meta.removeIptcTag("Iptc.Application2.City");
 
     if (d->sublocationCheck->isChecked())
-        exiv2Iface.setIptcTagString("Iptc.Application2.SubLocation", d->sublocationEdit->text());
+        meta.setIptcTagString("Iptc.Application2.SubLocation", d->sublocationEdit->text());
     else
-        exiv2Iface.removeIptcTag("Iptc.Application2.SubLocation");
+        meta.removeIptcTag("Iptc.Application2.SubLocation");
 
     if (d->provinceCheck->isChecked())
-        exiv2Iface.setIptcTagString("Iptc.Application2.ProvinceState", d->provinceEdit->text());
+        meta.setIptcTagString("Iptc.Application2.ProvinceState", d->provinceEdit->text());
     else
-        exiv2Iface.removeIptcTag("Iptc.Application2.ProvinceState");
+        meta.removeIptcTag("Iptc.Application2.ProvinceState");
 
     if (d->countryCheck->isChecked())
     {
         QString countryName = d->countryCB->currentText().mid(6);
         QString countryCode = d->countryCB->currentText().left(3);
-        exiv2Iface.setIptcTagString("Iptc.Application2.CountryCode", countryCode);
-        exiv2Iface.setIptcTagString("Iptc.Application2.CountryName", countryName);
+        meta.setIptcTagString("Iptc.Application2.CountryCode", countryCode);
+        meta.setIptcTagString("Iptc.Application2.CountryName", countryName);
     }
     else if (d->countryCheck->isValid())
     {
-        exiv2Iface.removeIptcTag("Iptc.Application2.CountryCode");
-        exiv2Iface.removeIptcTag("Iptc.Application2.CountryName");
+        meta.removeIptcTag("Iptc.Application2.CountryCode");
+        meta.removeIptcTag("Iptc.Application2.CountryName");
     }
 
 #if KEXIV2_VERSION >= 0x010000
-    exifData = exiv2Iface.getExifEncoded();
+    exifData = meta.getExifEncoded();
 #else
-    exifData = exiv2Iface.getExif();
+    exifData = meta.getExif();
 #endif
 
-    iptcData = exiv2Iface.getIptc();
+    iptcData = meta.getIptc();
 }
 
 }  // namespace KIPIMetadataEditPlugin
