@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2007-10-24
  * Description : XMP workflow status properties settings page.
  *
- * Copyright (C) 2007-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -37,7 +37,7 @@ class XMPProperties : public QWidget
 
 public:
 
-    XMPProperties(QWidget* parent);
+    XMPProperties(QWidget* const parent);
     ~XMPProperties();
 
     void applyMetadata(QByteArray& xmpData);
