@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2011-05-23
  * Description : a plugin to create panorama by fusion of several images.
  * Acknowledge : based on the expoblending plugin
  *
- * Copyright (C) 2011 by Benjamin Girault <benjamin dot girault at gmail dot com>
- * Copyright (C) 2009-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2012 by Benjamin Girault <benjamin dot girault at gmail dot com>
+ * Copyright (C) 2009-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -26,6 +26,7 @@
 
 // Qt includes
 
+#include <QDir>
 #include <QLabel>
 #include <QPixmap>
 #include <QGroupBox>
@@ -50,19 +51,27 @@ namespace KIPIPanoramaPlugin
 
 struct LastPage::LastPagePriv
 {
-    LastPagePriv() : title(0), saveSettingsGroupBox(0), fileTemplateKLineEdit(0), savePtoCheckBox(0), mngr(0) {}
+    LastPagePriv()
+        : title(0),
+          saveSettingsGroupBox(0),
+          fileTemplateKLineEdit(0),
+          savePtoCheckBox(0),
+          mngr(0)
+    {
+    }
 
     QLabel*    title;
 
     QGroupBox* saveSettingsGroupBox;
     KLineEdit* fileTemplateKLineEdit;
     QCheckBox* savePtoCheckBox;
+    QLabel*    warningLabel;
 
     Manager*   mngr;
 };
 
-LastPage::LastPage(Manager* mngr, KAssistantDialog* dlg)
-     : KIPIPlugins::WizardPage(dlg, i18n("<b>Panorama Stitched</b>")),
+LastPage::LastPage(Manager* const mngr, KAssistantDialog* const dlg)
+     : KPWizardPage(dlg, i18n("<b>Panorama Stitched</b>")),
        d(new LastPagePriv)
 {
     KConfig config("kipirc");
@@ -74,8 +83,6 @@ LastPage::LastPage(Manager* mngr, KAssistantDialog* dlg)
     d->title->setOpenExternalLinks(true);
     d->title->setWordWrap(true);
 
-    QLabel* space             = new QLabel(vbox);
-
     QVBoxLayout *formatVBox   = new QVBoxLayout();
     d->saveSettingsGroupBox   = new QGroupBox(i18n("Save Settings"), vbox);
     d->saveSettingsGroupBox->setLayout(formatVBox);
@@ -101,6 +108,11 @@ LastPage::LastPage(Manager* mngr, KAssistantDialog* dlg)
                                           "This is useful if you want a different projection, modify the horizon or "
                                           "the center of the panorama, or modify the control points to get better results."));
     formatVBox->addWidget(d->savePtoCheckBox);
+    d->warningLabel = new QLabel(d->saveSettingsGroupBox);
+    d->warningLabel->hide();
+    formatVBox->addWidget(d->warningLabel);
+
+    QLabel* space             = new QLabel(vbox);
     vbox->setStretchFactor(space, 2);
 
     setPageWidget(vbox);
@@ -111,6 +123,9 @@ LastPage::LastPage(Manager* mngr, KAssistantDialog* dlg)
     connect(d->fileTemplateKLineEdit, SIGNAL(textChanged(QString)),
             this, SLOT(slotTemplateChanged(QString)));
 
+    connect(d->savePtoCheckBox, SIGNAL(stateChanged(int)),
+            this, SLOT(slotPtoCheckBoxChanged(int)));
+
     connect(d->mngr->thread(), SIGNAL(starting(KIPIPanoramaPlugin::ActionData)),
             this, SLOT(slotAction(KIPIPanoramaPlugin::ActionData)));
 }
@@ -128,6 +143,7 @@ LastPage::~LastPage()
 void LastPage::resetTitle()
 {
     slotTemplateChanged(d->fileTemplateKLineEdit->text());
+    checkFiles();
 }
 
 void LastPage::copyFiles()
@@ -157,7 +173,12 @@ void LastPage::slotAction(const KIPIPanoramaPlugin::ActionData& ad)
             {
                 case COPY:
                 {
-                    //TODO
+                    disconnect(d->mngr->thread(), SIGNAL(finished(KIPIPanoramaPlugin::ActionData)),
+                               this, SLOT(slotAction(KIPIPanoramaPlugin::ActionData)));
+
+                    emit signalCopyFinished(false);
+                    d->warningLabel->setText(i18n("<qt><p><font color=\"red\"><b>Error:</b> "
+                                                  "%1</font></p></qt>", ad.message));
                     break;
                 }
                 default:
@@ -173,7 +194,10 @@ void LastPage::slotAction(const KIPIPanoramaPlugin::ActionData& ad)
             {
                 case COPY:
                 {
-                    emit signalCopyFinished();
+                    disconnect(d->mngr->thread(), SIGNAL(finished(KIPIPanoramaPlugin::ActionData)),
+                               this, SLOT(slotAction(KIPIPanoramaPlugin::ActionData)));
+
+                    emit signalCopyFinished(true);
                     break;
                 }
                 default:
@@ -186,7 +210,7 @@ void LastPage::slotAction(const KIPIPanoramaPlugin::ActionData& ad)
     }
 }
 
-void LastPage::slotTemplateChanged(const QString& fileTemplate)
+void LastPage::slotTemplateChanged(const QString&)
 {
     d->title->setText(i18n("<qt>"
                            "<p><h1><b>Panorama Stitching is Done</b></h1></p>"
@@ -199,10 +223,14 @@ void LastPage::slotTemplateChanged(const QString& fileTemplate)
                            "the stitching process will be copied at the same time (those are "
                            "TIFF files that can be big).</p>"
                            "</qt>",
-                           d->mngr->preProcessedMap().begin().key().directory(),
-                           panoFileName(fileTemplate),
-                           fileTemplate + ".pto"
+                           QDir::toNativeSeparators(d->mngr->preProcessedMap().begin().key().directory())
                           ));
+    checkFiles();
+}
+
+void LastPage::slotPtoCheckBoxChanged(int)
+{
+    checkFiles();
 }
 
 QString LastPage::panoFileName(const QString& fileTemplate) const
@@ -210,11 +238,35 @@ QString LastPage::panoFileName(const QString& fileTemplate) const
     switch (d->mngr->format())
     {
         default:
-        case ActionThread::JPEG:
+        case JPEG:
             return fileTemplate + ".jpg";
-        case ActionThread::TIFF:
+        case TIFF:
             return fileTemplate + ".tif";
     }
 }
 
+void LastPage::checkFiles()
+{
+    QFile panoFile(d->mngr->preProcessedMap().begin().key().directory() + '/' + panoFileName(d->fileTemplateKLineEdit->text()));
+    QFile ptoFile(d->mngr->preProcessedMap().begin().key().directory() + '/' + d->fileTemplateKLineEdit->text() + ".pto");
+    if (panoFile.exists() || (d->savePtoCheckBox->isChecked() && ptoFile.exists()))
+    {
+        emit signalIsValid(false);
+        resetWarningMsg();
+        d->warningLabel->show();
+    }
+    else
+    {
+        emit signalIsValid(true);
+        d->warningLabel->hide();
+    }
+
+}
+
+void LastPage::resetWarningMsg()
+{
+    d->warningLabel->setText(i18n("<qt><p><font color=\"red\"><b>Warning:</b> "
+                                  "This file already exists.</font></p></qt>"));
+}
+
 }   // namespace KIPIPanoramaPlugin
