@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2011-05-23
  * Description : Autodetect pto2mk binary program and version
  *
- * Copyright (C) 2011 by Benjamin Girault <benjamin dot girault at gmail dot com>
+ * Copyright (C) 2011-2012 by Benjamin Girault <benjamin dot girault at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -25,27 +25,35 @@
 
 // Local includes
 
-#include "binaryiface.h"
+#include "kpbinaryiface.h"
 
 using namespace KIPIPlugins;
 
 namespace KIPIPanoramaPlugin
 {
 
-class Pto2MkBinary : public BinaryIface
+class Pto2MkBinary : public KPBinaryIface
 {
 
 public:
 
-    Pto2MkBinary();
-    ~Pto2MkBinary();
+    Pto2MkBinary()
+        : KPBinaryIface(QString("pto2mk"),
+                        QString("2010.4"), 
+                        QString("pto2mk version "),
+                        2, 
+                        QString("Hugin"),
+                        QString("http://hugin.sourceforge.net"),
+                        QString("Panorama"),
+                        QStringList("-h")
+                       )
+        { 
+            setup(); 
+        }
 
-    QString path()           const;
-    QString minimalVersion() const;
-    KUrl    url()            const;
-    QString projectName()    const;
-
-    void    checkSystem();
+    ~Pto2MkBinary()
+    {
+    }
 };
 
 } // namespace KIPIPanoramaPlugin
